
# line 153 "verilog.yacc"
#include <stdio.h>

/* assign integer values to TRUE and FALSE */

#define TRUE  	1
#define FALSE 	0

/* codes defining the position of the wire or element */

#define INTERNAL	0 
#define INP  		1
#define OUTP 		2
#define BIDIR 		3

/* assign integer values to gate types */

#define D_FLIP_FLOP 	44
#define AND_GATE	 0
#define NAND_GATE	 1
#define OR_GATE	 	 2
#define NOR_GATE	 3
#define XOR_GATE	30
#define	XNOR_GATE	31
#define	BUFFER    	 4
#define INVERTER	 5
#define DELAYED_WIRE    99

/* define element (E) type */

#define E_WIRE		 1
#define E_LOGIC_GATE	 5
#define E_BEHAVIORAL 	15

/*******************************************************************************************************************

	The following four macros were taken from Prof. Alva L. Couch's ht list handling library, 
	      Copyright 1992 by Alva L. Couch, Dept. of Computer Science, Tufts University

*******************************************************************************************************************/

#define MALLOC_TYPE(type) (type *) malloc (sizeof(type))

#define HT_HEAD(a,h,t) \
	ht_head((Htelem *)a,(Htelem **)h, (Htelem **)t)
#define HT_TAIL(a,h,t) \
	ht_tail((Htelem *)a,(Htelem **)h, (Htelem **)t)
#define HT_UNLINK(a,h,t) \
	ht_unlink((Htelem *)a, (Htelem **)h, (Htelem **)t)

/******************************************************************************************************************/

int IDnum = 0, wirecount = 0, elemcount = 0, modulecount = 0; 	/*indexes of elem, ID, and module counts*/ 

int i, x;    		 /*indexes*/
int position;	 /*used to store beginning of input and output blocks to set position*/
int cnxn_index;		 /*used to store the link bit of elem connections*/
int delay_index = 1;     /*used to store the index of the delay table*/
int Is_in_list;		 /*Boolean used to denote whether a wire name is in the list of internal wires*/
int PIs = 0, POs = 0, BiDirectionals = 0; 	/*counts of Primary Inputs, Outputs, and Bidirectionals*/

/*******************************************************************************************************************

	Definition of struct used in Prof. Alva L. Couch's ht linked list library

*******************************************************************************************************************/

typedef struct htelem { 
    struct htelem *next; /* next pointer in main list */
    /* anything goes here */ 
} Htelem;

/******************************************************************************************************************/


typedef struct Wire{             	/*used to store internal wire connection information*/

	struct Wire *next;		/*pointer to next wire in list*/

	char *name;			/*name of wire*/

	int fanin;			/*number of gates which fanin to the wire*/

	int fanout;			/*number of gates to which the wire fans out*/ 

	int link_bit; 			/*stores index of output from element (0 if 1 output,*/
					/*0 or 1 if 2 outputs, 0, 1, or 2 if 3 outputs, etc.)*/

	struct ELEM *elem;		/*element (gate or input wire) which the internal wire originates from*/

	struct CONNECTION *couthead;	/*head of output connection list*/

	struct CONNECTION *couttail;	/*tail of output connection list*/

	struct CONNECTION *conn;	/*pointer used to cycle through connection list.  The connection list*/
					/*stores pointers to the elements which accept this wire as an input.*/
					/*Each internal wire stores and maintains its own connection list.   */
} Wire;



typedef struct CONNECTION{             	/*used to store info on one inter-elem connection*/

	struct CONNECTION *next;	/*pointer to next connection in list*/

	struct ELEM *ept;		/*connections which are pointed to by internal wires store a pointer */
					/*to an element.  This element is one of (possibly) many which accept*/
					/*the wire as an input.*/

	struct Wire *wpt;		/* connections which are pointed to by elements store a pointer to an  */
					/*internal wire.  This wire is one of many which are inputs to the elem*/
} CONNECTION;



typedef struct DELAY{   	     	/*delay information*/

	struct DELAY *next;		/*LINKED LIST NOT YET IMPLEMENTED FOR DELAY TABLE*/

	int rise, fall;			/*rise and fall times of each gate.  Gates have an index which*/
					/*points to a certain rise and fall in the delay table.       */
} DELAY;



DELAY delay_table[30];		   	/*delay table*/


	
typedef struct ELEM{	 		/*struct used to store info on wires(inputs and delay wires) + elems*/

	struct ELEM *next;		/*pointer to next element in list*/

	char *name;			/*name of element*/

	int position;			/*O for internal, 1 for input, 2 for output, 3 for bidirectional*/

	int index;			/*our index of the element in the element list*/

	int logictype;			/*type of logic of element (1 if wire, 5 if gate, 15 if behavioral)*/

	int gatetype;			/*if a gate or behavioral element, "gatetype" stores the sub-class */

	int connection;			/*Connection index of the element (UNUSED, as of Aug 3, '98)*/

	int outputs;			/*number of outputs of the element*/

	int inputs;			/*number of inputs which enter the gate*/
	
	int delay;			/*delay index of element -- stores location of the correct*/ 
					/*rise and fall values of the element in the delay table  */

	int sim_lev;			/*simulation level -- the depth of 0-delay elements in the circuit.*/
					/*Input wires are assigned a value of 1 for sim_lev, while gates   */
					/*with a non-zero delay are assigned a value of zero.  All other   */
					/*gates are assigned a value of 1 more than the greatest sim_lev   */
					/*value of all gates which are input into the gate being analyzed. */

	struct CONNECTION *cinhead;	/*head of input connection list*/

	struct CONNECTION *cintail;	/*tail of input connection list*/

	struct CONNECTION *conn;	/*pointer used to cycle through the connection list.  The connection*/
					/*list stores pointers to internal wires which the current element  */
					/*uses as inputs.  Each element maintains its own connection list.  */
} ELEM;



	/***** WIRELIST INSTANTIATION *****/

Wire *wirelist = NULL;		/*Internal wire pointer used for cycling through the wirelist.    */
Wire *whead = NULL;		/*The head and tail of the wirelist are stored in whead and wtail.*/
Wire *wtail = NULL;

	/***** ELEMLIST INSTANTIATION *****/
	
ELEM *elemlist = NULL;		/*Internal element pointer used for cycling through the elemlist. */
ELEM *tempelem = NULL; 			/*Temporary element pointer used for short term storage*/
ELEM *ehead = NULL;		/*The head and tail of the elemlist are stored in ehead and etail.*/	
ELEM *etail = NULL;

Htelem *ht_make(int);	
Htelem *ht_head(Htelem*,Htelem**,Htelem**);
Htelem *ht_tail(Htelem*,Htelem**,Htelem**);
Htelem *ht_unlink(Htelem*,Htelem**,Htelem**);

int LevelStep(ELEM *elemlist);


# line 343 "verilog.yacc"
typedef union
#ifdef __cplusplus
	YYSTYPE
#endif
{
	int n;		/*type classes for tokens and non-terminal identifiers (defined below)*/ 
	char *txt;	/*To define a token or non-terminal identifier as a certain class, the*/
	char c;		/*class is denoted in the <> brackets after the %token or %type decl. */
} YYSTYPE;
# define DECIMAL_NUMBER 257
# define UNSIGNED_NUMBER 258
# define EDGE_OR_UNSIGNED 259
# define ZERO_OR_ONE 260
# define BINARY_NUMBER 261
# define OCTAL_NUMBER 262
# define HEX_NUMBER 263
# define REAL_NUMBER 264
# define BINARY_OPERATOR 265
# define UNARY_OPERATOR 266
# define OPERATOR 267
# define EDGE_DESCRIPTOR 268
# define EDGE_OR_BINARY_OPERATOR 269
# define EX 270
# define LEVEL_SYMBOL 271
# define EDGE_SYMBOL 272
# define EQUAL 273
# define OPENPAREN 274
# define CLOSEPAREN 275
# define OPENCURLYBRAC 276
# define CLOSECURLYBRAC 277
# define BACKSLASH 278
# define COMMA 279
# define OPENSQBRAC 280
# define CLOSESQBRAC 281
# define POUND 282
# define AT 283
# define COLON 284
# define SEMICOLON 285
# define QUESTIONMARK 286
# define PLUS 287
# define MINUS 288
# define TILDA 289
# define DOT 290
# define SINGLE_QUOTE 291
# define LESSOREQUAL 292
# define DOUBLERIGHTARROW 293
# define EQUIV_EXPR 294
# define RIGHTARROW 295
# define STARARROWRIGHT 296
# define TRIAMPERSAND 297
# define DOLLAR 298
# define DES_ASSIGNMENT 299
# define KNOWN_BIT 300
# define ONE_KNOWN_BIT 301
# define UNKNOWN_BIT 302
# define ESCAPED_IDENTIFIER 303
# define SIMPLE_IDENTIFIER 304
# define STRING 305
# define ALWAYS 306
# define AND 307
# define ASSIGN 308
# define BEGN 309
# define BODY 310
# define BUF 311
# define BUFIF0 312
# define BUFIF1 313
# define CASE 314
# define CASEX 315
# define CASEZ 316
# define CMOS 317
# define DEASSIGN 318
# define DEFAULT 319
# define DEFPARAM 320
# define DFF 321
# define DISABLE 322
# define EDGE 323
# define ELSE 324
# define END 325
# define ENDCASE 326
# define ENDFUNCTION 327
# define ENDMODULE 328
# define ENDPRIMITIVE 329
# define ENDSPECIFY 330
# define ENDTABLE 331
# define ENDTASK 332
# define ENDUNIT 333
# define EVENT 334
# define FOR 335
# define FORCE 336
# define FOREVER 337
# define FORK 338
# define FUNCTION 339
# define HIGHZ0 340
# define HIGHZ1 341
# define HOLD 342
# define IF 343
# define IFNONE 344
# define IN 345
# define INITL 346
# define INOUT 347
# define INPUT 348
# define INTEGER 349
# define INV 350
# define JOIN 351
# define LARGE 352
# define MACROMODULE 353
# define MEDIUM 354
# define MODULE 355
# define NAND 356
# define NEGEDGE 357
# define NMOS 358
# define NOR 359
# define NOT 360
# define NOTIF0 361
# define NOTIF1 362
# define OR 363
# define OUT 364
# define OUTPUT 365
# define PARAMETER 366
# define PATHPULSE 367
# define PERIOD 368
# define PMOS 369
# define POSEDGE 370
# define PRIMITIVE 371
# define PULL0 372
# define PULL1 373
# define PULLDOWN 374
# define PULLUP 375
# define REAL 376
# define REALTIME 377
# define RCMOS 378
# define RECOVERY 379
# define REG 380
# define RELEASE 381
# define REPEAT 382
# define RNMOS 383
# define RPMOS 384
# define RTRAN 385
# define RTRANIF0 386
# define RTRANIF1 387
# define SCALARED 388
# define SETUP 389
# define SETUPHOLD 390
# define SKEW 391
# define SMALL 392
# define SPECIFY 393
# define SPECPARAM 394
# define STRONG0 395
# define STRONG1 396
# define SUPPLY0 397
# define SUPPLY1 398
# define TABLE 399
# define TASK 400
# define TIME 401
# define TRAN 402
# define TRANIF0 403
# define TRANIF1 404
# define TRI 405
# define TRI0 406
# define TRI1 407
# define TRIAND 408
# define TRIOR 409
# define TRIREG 410
# define UNIT 411
# define VECTORED 412
# define WAIT 413
# define WAND 414
# define WEAK0 415
# define WEAK1 416
# define WHILE 417
# define WIDTH 418
# define WIRE 419
# define WOR 420
# define XNOR 421
# define XOR 422

#include <inttypes.h>

#ifdef __STDC__
#include <stdlib.h>
#include <string.h>
#else
#include <malloc.h>
#include <memory.h>
#endif

#include <values.h>

#if defined(__cplusplus) || defined(__STDC__)

#if defined(__cplusplus) && defined(__EXTERN_C__)
extern "C" {
#endif
#ifndef yyerror
#if defined(__cplusplus)
	void yyerror(const char *);
#endif
#endif
#ifndef yylex
	int yylex(void);
#endif
	int yyparse(void);
#if defined(__cplusplus) && defined(__EXTERN_C__)
}
#endif

#endif

#define yyclearin yychar = -1
#define yyerrok yyerrflag = 0
extern int yychar;
extern int yyerrflag;
YYSTYPE yylval;
YYSTYPE yyval;
typedef int yytabelem;
#ifndef YYMAXDEPTH
#define YYMAXDEPTH 150
#endif
#if YYMAXDEPTH > 0
int yy_yys[YYMAXDEPTH], *yys = yy_yys;
YYSTYPE yy_yyv[YYMAXDEPTH], *yyv = yy_yyv;
#else	/* user does initial allocation */
int *yys;
YYSTYPE *yyv;
#endif
static int yymaxdepth = YYMAXDEPTH;
# define YYERRCODE 256

# line 2054 "verilog.yacc"


#define NET_EXTENSION ".dee"
#define DES_EXTENSION ".des"
#define VERILOG_EXTENSION ".v" 

extern FILE *yyin, *yyout;
extern int yydebug;

/*******************************************************************************************************************

 FILENAME:		VERILOG.YACC

 FUNCTION NAME: 	main(int argc, char** argv)

 CREATION DATE:		August 3, 1998

 AUTHOR:		Ben Foster

 PARAMETERS:	Input:  Name of Verilog file to be translated (minus the ".v" extension)
			Name of DEE file to be created and written to (minus the ".dee" extension)

 PURPOSE:		Accepts the names of the Verilog file to be read and the DEE file to be written to.  
			The main function opens the Verilog file as read only and the DEE file as write to, 
			calls the yyparse() function to begin parsing the Verilog file, and closes the Verilog 
			file after the parsing has finished.  "Main()" then analyzes the data structures 
			created by the yacc routine, modifying them as necessary and finally printing out 
			the DEE file using these data structures.
 
 SIDE EFFECTS:		The data structures "wirelist" and "elemlist" are modified as needed in order to
			clean up the DEE printing.  Loose wires are removed, and some values, such as
			"sim_lev", are modified in the "main()" function.

 COMMENTS: 		

 HISTORY:		Unmodified

*******************************************************************************************************************/

main(argc, argv)
int argc;
char** argv;
{
  char* infilename;		/*strings for input and output files. */
  char* outfilename;
  
  int mod_tb_addr = 0, sym_tb_addr = 0;     	/*pointers to module address and SMT address*/

  int Inputs=0, Outputs=0, Fanin=0, Fanout=0;  	/*initialize number of inputs, outputs, fanin, fanout*/

  int max_delay;				/*storage for max_delay, used in line 22 of the DEE */

  int loose_inputs = 0, loose_outputs = 0, loose_bidirs = 0; 		/*number of loose wires,*/
									/*one for each type*/

  int shift = 0;  			/*used to store shift caused by removing elements*/ 
  
  static long head_symt_addr;		/* symbol table address */
  static long head_modt_addr;		/* module table address */

  long	ctime;				/* stores 

  /* missing parameter check */
    
  /* yydebug=1; */

  /**Check for correct number of parameters**/

  if (argc!=3) {
    fprintf(stderr, "Incorrect number of arguments in command line.\n"
	    "Exiting program.\n");
    fprintf(stderr, "Correct usage: parse <name of Verilog file> <name of Dee file>\n");
    exit(0);
  }

  /***** OPEN FILES *****/
  /* input file */

  if (argc>1){
    infilename=(char*)malloc(sizeof(char)*strlen(argv[1])+1);
    sprintf (infilename, "%s%s", argv[1], VERILOG_EXTENSION);
    if ((yyin=fopen(infilename,"r"))==NULL){
      sprintf (infilename, "%s%s", argv[1], DES_EXTENSION);
      if ((yyin=fopen(infilename,"r"))==NULL){	
        yyerror("unable to open inputfile");
      }
    }    
    argc--;
    argv++;
  }else{
    infilename=" ";
  }
	
  /* output file */
  if (argc>1){
    sprintf (infilename, "%s%s", argv[1], NET_EXTENSION);
    if ((yyout=fopen(infilename,"w"))==NULL){
      yyerror("could not open outputfile\n");
    }
  }
  
  yyparse();
  
  fclose(yyin);
  	
			/*List Modification*/
  for(wirelist = whead; wirelist; wirelist=wirelist->next){

	Fanout += wirelist->fanout;
	Fanin += wirelist->elem->inputs; 	
	Outputs += wirelist->elem->outputs;
	Inputs += wirelist->elem->inputs;

	if(wirelist->fanout!=0){  /*empty*/
	}
	
	else if(wirelist->fanin!=0){	/*for wire with fanin but no fanout, set as output*/

		for(wirelist->elem->conn=wirelist->elem->cinhead; wirelist->elem->conn; 
		    wirelist->elem->conn=wirelist->elem->conn->next){
		  wirelist->elem->position = OUTP;
		}						
	}	
	else{				/*for wire with no fanin or fanout, remove entirely*/
	 	HT_UNLINK(wirelist->elem, &ehead, &etail);
		if(wirelist->elem->position == INP) loose_inputs++;
		if(wirelist->elem->position == OUTP) loose_outputs++;
		if(wirelist->elem->position == BIDIR) loose_bidirs++;
		HT_UNLINK(wirelist, &whead, &wtail);
	}
  }

  PIs -= loose_inputs;			/*correction of Primary inputs, outputs, Bidirectionals, # of elems*/
  POs -= loose_outputs;
  elemcount -= (POs + loose_outputs + loose_inputs);
  BiDirectionals -= loose_bidirs;

  Fanin -= (PIs + loose_inputs);	/*correction of Fanin, Outputs, and Inputs*/
  Outputs -= (loose_outputs + loose_inputs);
  Inputs -= (loose_outputs + loose_inputs);


  wirecount = PIs + BiDirectionals;     /*Set wirecount*/

  i=0;					/*Reset indexes for modified wirelist*/
  for(wirelist = whead; wirelist; wirelist=wirelist->next){
	wirelist->elem->index = i++;
  }

			/*set first element of delay table to ZERO*/
  delay_table[0].rise = 0;
  delay_table[0].fall = 0;

	
			/*set all DFF's rise and fall delay to 1 if not specified*/
  for(elemlist = ehead; elemlist!=NULL; elemlist=elemlist->next){
    if(elemlist->logictype == E_LOGIC_GATE && elemlist->gatetype == D_FLIP_FLOP && elemlist->delay == 0){
      elemlist->sim_lev = 0;
      for(i=0; i<delay_index; i++){
	if(delay_table[i].rise == 1 && delay_table[i].fall == 1) elemlist->delay = i;
      }
      if(elemlist->delay == 0){
	delay_table[delay_index].rise = 1;
	delay_table[delay_index].fall = 1;
	elemlist->delay = delay_index;
	delay_index++;
      }
    }  
  }
			/*preparation of elemlist for calculation of sim_levels*/	
  for(elemlist = ehead; elemlist; elemlist=elemlist->next){
    if(elemlist->delay == 0 && elemlist->position != INP){
      elemlist->sim_lev = -1;		/*Initialization of "sim_lev" in element list for*/
				  	/*LevelStep() function called in following "for" loop*/
    }
  }
			/*Call LevelStep() if the element has delay or is an output element.*/
			/*An output gate or a gate with a non-zero delay is the starting    */
			/*point for sim_lev calculation.  (See LevelStep() function dscrptn)*/
  for(elemlist = ehead; elemlist; elemlist=elemlist->next){
    if(elemlist->position == OUTP || elemlist->delay != 0){
      i = LevelStep(elemlist);		/*"i" is garbage, used to start recursive LevelStep()*/
    }
  } 

			/*find max delay*/ 
  max_delay = 0;
  for(i=0; i<delay_index; i++){
	if(max_delay < delay_table[i].rise) max_delay = delay_table[i].rise;
	if(max_delay < delay_table[i].fall) max_delay = delay_table[i].fall;
  }
 
  for(wirelist = whead; wirelist; wirelist=wirelist->next){
	for(wirelist->conn=wirelist->couthead; wirelist->conn; 
		    wirelist->conn=wirelist->conn->next){
	}
  }

/*BEGIN THE HEADER INFORMATION*/
	
  	fprintf(yyout, "3.0\n");
	fprintf(yyout, "%s\n", argv[1]);
	head_symt_addr = ftell(yyout);		/*store position of SMT address location in DEE*/
			
        fprintf(yyout, "%8d\n", 0);

        head_modt_addr = ftell(yyout);		/*store position of module address location in DEE*/
			
        fprintf(yyout, "%8d\n", 0);
	fprintf(yyout, "0\n");
	fprintf(yyout, "%d 1\n", PIs);  
	fprintf(yyout, "%d 1\n", POs);  
	fprintf(yyout, "%d 0\n", BiDirectionals); 
 	fprintf(yyout, "0\n");  
	fprintf(yyout, "0\n");  
	fprintf(yyout, "%d 1\n", wirecount); 
	fprintf(yyout, "0 0\n");
	fprintf(yyout, "0\n");  
	fprintf(yyout, "%d\n", elemcount - wirecount);  
	fprintf(yyout, "0\n");  
	fprintf(yyout, "0\n");  
	fprintf(yyout, "0\n");  
	fprintf(yyout, "0\n");  
	fprintf(yyout, "0\n");  
	fprintf(yyout, "0\n");  
	fprintf(yyout, "0\n");  
	fprintf(yyout, "%d -9 0 %d\n", delay_index, max_delay); 					
	fprintf(yyout, "0\n"); 		/*# of initialization tables*/
	fprintf(yyout, "0 0\n");  
	fprintf(yyout, "0 0\n");  
	fprintf(yyout, "5 0\n");  
	fprintf(yyout, "1 0\n");  
	fprintf(yyout, "-1 -1\n");  	
	fprintf(yyout, "30031977\n");
	fprintf(yyout, "094500\n");  
	time(&ctime);          
        fprintf(yyout, "%d\n", ctime);
	fprintf(yyout, "333\n");  
	fprintf(yyout, "1 1 0 1\n");
	fprintf(yyout, "%d %d %d %d %d %d\n", elemcount, Fanin, Inputs - PIs,
		Fanout, Outputs, BiDirectionals);
	fprintf(yyout, "0 0 0\n");  
	fprintf(yyout, "0 0\n");  
	fprintf(yyout, "0 0\n");  
	fprintf(yyout, "0 0\n");  
	fprintf(yyout, "0 0\n");  
	fprintf(yyout, "0 0\n");  

/*END OF HEADER*/
/*DELAY TABLE*/
	
	for(i=0; i<delay_index; i++){
	  fprintf(yyout, "%d %d\n", delay_table[i].rise, delay_table[i].fall);
	}

/*END OF DELAY TABLE*/
/*TOPOLOGICAL INFORMATION*/
	
	  for(wirelist = whead; wirelist; wirelist=wirelist->next){
	      fprintf(yyout, "%d %d %d 0\n", wirelist->elem->position, wirelist->elem->logictype,
					     wirelist->elem->sim_lev);
	  
	      if(wirelist->elem->logictype==E_WIRE)
		fprintf(yyout, "1 128 %d %d %d %d %d %d\n", wirelist->elem->delay, wirelist->fanout, 
			wirelist->fanin, wirelist->elem->connection, wirelist->elem->outputs,
			wirelist->elem->inputs);
	      else 
   		fprintf(yyout, "%d %d 1 1 %d %d %d %d\n", wirelist->elem->gatetype, wirelist->elem->delay,
			wirelist->fanout, wirelist->elem->inputs, wirelist->elem->outputs,
			wirelist->elem->inputs);
	
              for(wirelist->conn = wirelist->couthead; wirelist->conn; 
		  wirelist->conn = wirelist->conn->next){
        	fprintf(yyout, "%d %d %d 0\n", wirelist->conn->ept->logictype,
			  wirelist->conn->ept->index, wirelist->link_bit);
	      }
	      
	      for(wirelist->elem->conn = wirelist->elem->cinhead; wirelist->elem->conn; 
		  wirelist->elem->conn = wirelist->elem->conn->next){
		fprintf(yyout, "%d %d %d 0\n", 
			  wirelist->elem->conn->wpt->elem->logictype,
			  wirelist->elem->conn->wpt->elem->index,
			  wirelist->elem->conn->wpt->link_bit);
	      }
	    }
	  
/*END OF TOPOLOGICAL INFORMATION*/

/*INITIALIZATION TABLE NOT IMPLEMENTED*/

/*SYMBOL TABLE*/

	/*Find the Symbol Table Address*/
	/* store the symbol table start address */
        sym_tb_addr = ftell(yyout);

  	fprintf(yyout, "%d 0\n", modulecount);
	fprintf(yyout, "%s 0 %d %s -1 -1 -1 0\n", argv[1], elemcount - 1, argv[1]);
	fprintf(yyout, "%s %d\n", argv[1], elemcount*2 - wirecount);
	for(wirelist = whead; wirelist!=NULL; wirelist=wirelist->next){
	  for(i=0; i<wirelist->elem->outputs; i++){
	    fprintf(yyout, "%d %d %d %s\n", wirelist->elem->index, wirelist->link_bit, 
			wirelist->elem->logictype, wirelist->elem->name);
	    if(wirelist->elem->logictype == 5){
	      if(wirelist->name != NULL)
	       	fprintf(yyout, "%d %d 1 %s\n", wirelist->elem->index, wirelist->link_bit, wirelist->name);
	      else fprintf(yyout, "%d %d 1 %s\n", wirelist->elem->index, wirelist->link_bit, 
			   wirelist->elem->name);
	    }
	  }
	}
	/* store the symbol table start address */
        mod_tb_addr = ftell(yyout);
	
	fprintf(yyout, "%s 0 0\n", argv[1]);
	
		/*find the symbol table address location in the Header and print the information*/
	fseek(yyout, head_symt_addr, 0);
        fprintf(yyout, "%8d", sym_tb_addr);

		/*find the module table address location in the Header and print the information*/		
        fseek(yyout, head_modt_addr, 0);		
        fprintf(yyout, "%8d", mod_tb_addr);

	exit(0);

/*END OF SYMBOL TABLE*/
}
/*END OF MAIN(INT ARGC, CHAR** ARGV)*/


/*******************************************************************************************************************

 FILENAME:		VERILOG.YACC

 FUNCTION NAME: 	LevelStep(ELEM *elemlist)

 CREATION DATE:		August 3, 1998
	
 AUTHOR:		Ben Foster

 PARAMETERS:	Input: 	pointer to the element list
		Output:	integer representing the simulation level of the gate which called LevelStep() 
			(Greatest sim_level of all input elements to current gate + 1)

 PURPOSE:		This function is used to cycle through all the elements in the elemlist, modifying the
			simulation level of each zero delay element.  The simulation level is used with zero
			delay elements so the MCS simulator knows in which order to evaluate them.  This 
			recursive function begins with either output elements or elements which have been 
			assigned a non-zero delay, recursively checking every element which contributes to the
			original gates inputs, returning only when it encounters a primary input, another 
			element with non-zero delay, or an element which has already been assigned a 
			simulation level value.  The value returned is the greatest of all the sim_lev values
			of all the elements which have outputs fanning into the current gate, PLUS ONE.  This 
			essentially creates an increasing depth in the circuit, starting at one for the inputs
			and increasing by one more for each level deeper into the circuit.  The sim_level value
			for all elements with a non-zero delay will always be zero.

 SIDE EFFECTS:		The purpose of the function is to calculate the value of "sim_lev" for each element.  
			Once this is done, the original elemlist->sim_lev is modified.   

 COMMENTS: 		The sim_lev value for non-zero delay elements : ZERO.  For primary input elements : ONE.

 HISTORY:		Unmodified

*******************************************************************************************************************/

int LevelStep(ELEM *elemlist){

  int temp = 0, junk, greatest = 0;
  CONNECTION *tempconn; 

  for(elemlist->conn=elemlist->cinhead; elemlist->conn; elemlist->conn=elemlist->conn->next){
 
	tempconn = elemlist->conn;	/*save the current connection*/ 

    if(elemlist->conn->wpt->elem->sim_lev == 1 && elemlist->delay == 0){	/*set temp to 2 if the previous*/
	temp = elemlist->conn->wpt->elem->sim_lev + 1;				/* element is an input element */
    }

    else if(elemlist->delay != 0){					/*throw away the value returned if*/ 
	if(elemlist->conn->wpt->elem->sim_lev != -1){			/*the element has a non-zero delay*/
	  junk = elemlist->conn->wpt->elem->sim_lev;
	}
	else junk = LevelStep(elemlist->conn->wpt->elem);		/*if the previous gate's sim_lev has*/
    }									/*not been set, set it.*/
    else{
	if(elemlist->conn->wpt->elem->sim_lev != -1){			/*if the previous gate's sim_lev HAS  */
	  temp = elemlist->conn->wpt->elem->sim_lev + 1;		/*been set, set current gate's sim_lev*/
	}								/*to previous sim_lev + 1*/
	else temp = LevelStep(elemlist->conn->wpt->elem);		/*<<==Else, set previous gate's sim_lev*/
    }
    if(temp >= greatest) greatest = temp;			/*store greatest sim_lev value for entire*/
	elemlist->conn = tempconn; 				/*input connection list of each element  */
  }
  if(elemlist->position == INP) greatest = 1;			
  elemlist->sim_lev = greatest;					/*set sim_lev to greatest value found for */
								/*current gate */
  return greatest + 1;						/*return greatest + 1 for NEXT element*/
}
/*END OF LevelStep(ELEM *elemlist)*/

/*******************************************************************************************************************

 FILENAME:		VERILOG.YACC

 FUNCTION NAME: 	ht_make (int size)

 CREATION DATE:		1992 

 AUTHOR:		Prof. Alva L. Couch

 PARAMETERS:	Input:	integer "size": specifies the number of bytes needed to allocate for the new element
		Output: returns a new element

 PURPOSE:		This function creates a new element to be used in a linked list

 SIDE EFFECTS:		None
	
 COMMENTS:		!!BETTER TO USE THE "MALLOC_TYPE(type)" MACRO DEFINED AT THE BEGINNING OF THE PROGRAM!!

 HISTORY:		Unmodified

*******************************************************************************************************************/

/* create a list element */
Htelem *ht_make (int size)
{
    Htelem *temp;
    temp = (Htelem *) malloc (size);
    temp->next = NULL;	/* set pointer to NULL here, avoid mistakes later */
    return (temp);
}
/*END OF ht_make (int size)*/

/*******************************************************************************************************************

 FILENAME:		VERILOG.YACC

 FUNCTION NAME: 	ht_tail (Htelem *elem, Htelem **head, Htelem **tail)

 CREATION DATE:		1992 

 AUTHOR:		Prof. Alva L. Couch

 PARAMETERS:	Input:	element to be added  (*elem)
			head of element list (**head)
			tail of element list (**tail)
		Output: returns the added element

 PURPOSE:		This function attaches an element to the tail of a list specified by pointers to the 
			head and tail of the list.

 SIDE EFFECTS:		The tail pointer is redirected to point at the new element, which becomes the new tail
	
 COMMENTS:		!!BETTER TO USE THE "HT_TAIL(a,h,t)" MACRO DEFINED AT THE BEGINNING OF THE PROGRAM!!

 HISTORY:		Unmodified

*******************************************************************************************************************/

/* link an element to the tail of a head-tail list */
Htelem *ht_tail (Htelem *elem, Htelem **head, Htelem **tail)
{
    if (((*head) == NULL) || ((*tail) == NULL))  {  /* list started empty */
	(*head) = elem;
	(*tail) = elem;
    } else { /* put elem after tail element */
	(*tail)->next = elem;
	(*tail) = elem;
    }
    elem->next = NULL;
    return (elem);
} /* end of ht_tail */

/*******************************************************************************************************************

 FILENAME:		VERILOG.YACC

 FUNCTION NAME: 	ht_head (Htelem *elem, Htelem **head, Htelem **tail)

 CREATION DATE:		1992 

 AUTHOR:		Prof. Alva L. Couch

 PARAMETERS:	Input:	element to be added  (*elem)
			head of element list (**head)
			tail of element list (**tail)
		Output: returns the added element

 PURPOSE:		This function attaches an element to the head of a list specified by pointers to the 
			head and tail of the list.

 SIDE EFFECTS:		The head pointer is redirected to point at the new element, which becomes the new head
	
 COMMENTS:		!!BETTER TO USE THE "HT_HEAD(a,h,t)" MACRO DEFINED AT THE BEGINNING OF THE PROGRAM!!

 HISTORY:		Unmodified

*******************************************************************************************************************/
    
/* link an element to the head of a head-tail list */
Htelem *ht_head (Htelem *elem, Htelem **head, Htelem **tail)
{
    if (((*head) == NULL) || ((*tail) == NULL))  {  /* list started empty */
	(*head) = elem;
	(*tail) = elem;
	elem->next = NULL;
    } else { /* put elem before head element */
	elem->next = (*head);
	(*head) = elem;
    }
    return (elem);
} /* end of ht_head */

/*******************************************************************************************************************

 FILENAME:		VERILOG.YACC

 FUNCTION NAME: 	ht_unlink (Htelem *elem, Htelem **head, Htelem **tail)

 CREATION DATE:		1992 

 AUTHOR:		Prof. Alva L. Couch

 PARAMETERS:	Input:	element to be deleted (*elem)
			head of element list (**head)
			tail of element list (**tail)
		Output: returns the added element

 PURPOSE:		This function deletes an element from the list containing it.  This list is defined by
			by the pointers to the list's head and tail.

 SIDE EFFECTS:		The predecessor in the list's pointer to the next element (the element being unlinked)
			is redirected.
	
 COMMENTS:		!!BETTER TO USE THE "HT_UNLINK(a,h,t)" MACRO DEFINED AT THE BEGINNING OF THE PROGRAM!!

 HISTORY:		Unmodified

*******************************************************************************************************************/
    
/* unlink a segment from the master list */
Htelem *ht_unlink(Htelem *elem, Htelem **head, Htelem **tail) {
    Htelem *pred;

    if (elem == NULL) ;					/* nothing */

    else if (((*head) == NULL) || ((*tail) == NULL)) {	/* empty list */
        (*head) = NULL;
        (*tail) = NULL;
    } 

    else if (((*head) == elem) && ((*tail) == elem)) {	/* last elem  */
        (*head) = NULL;
        (*tail) = NULL;
    } 

    else if ((*head) == elem) {				/* off of top */
        (*head) = (*head)->next;
    } 

    else { 	   /* find the predecessor to segment, link around it */
        for (pred=(*head); 
	     (pred->next!=elem) && (pred->next!=NULL); 
	     pred=pred->next) ;
        if (pred->next == elem) {
	    pred->next = pred->next->next;
            if (elem == (*tail)) 
		(*tail) = pred; 
	}
    } 
    return (elem);
}  /* end: ht_unlink */

static const yytabelem yyexca[] ={
-1, 1,
	0, -1,
	-2, 0,
-1, 29,
	328, 280,
	-2, 210,
-1, 131,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 162,
	279, 318,
	285, 318,
	-2, 210,
-1, 167,
	279, 408,
	285, 408,
	-2, 210,
-1, 168,
	279, 40,
	285, 40,
	-2, 210,
-1, 169,
	279, 465,
	285, 465,
	-2, 210,
-1, 171,
	279, 465,
	285, 465,
	-2, 210,
-1, 180,
	279, 537,
	285, 537,
	-2, 210,
-1, 191,
	287, 210,
	288, 210,
	-2, 147,
-1, 210,
	279, 332,
	285, 332,
	-2, 210,
-1, 232,
	264, 509,
	265, 178,
	277, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 235,
	273, 82,
	292, 82,
	-2, 1,
-1, 244,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 265,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 271,
	258, 510,
	264, 510,
	-2, 639,
-1, 272,
	258, 511,
	264, 511,
	-2, 640,
-1, 282,
	257, 516,
	261, 516,
	262, 516,
	263, 516,
	-2, 361,
-1, 283,
	257, 645,
	261, 645,
	262, 645,
	263, 645,
	-2, 362,
-1, 284,
	264, 509,
	265, 178,
	277, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 303,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 304,
	279, 332,
	285, 332,
	-2, 210,
-1, 321,
	279, 161,
	285, 161,
	-2, 210,
-1, 344,
	279, 627,
	285, 627,
	-2, 210,
-1, 345,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 362,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 363,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 364,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 365,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 366,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 371,
	296, 259,
	-2, 425,
-1, 409,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 410,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 411,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 412,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 414,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 415,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 417,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 424,
	264, 509,
	265, 178,
	280, 178,
	284, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 425,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 427,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 431,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 438,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 442,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 445,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 455,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 464,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 465,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 467,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 483,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 543,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 550,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 561,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 576,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 580,
	264, 509,
	265, 178,
	280, 210,
	285, 178,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 582,
	264, 509,
	265, 178,
	280, 210,
	285, 178,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 584,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 589,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 590,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	284, 210,
	290, 210,
	-2, 178,
-1, 609,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 610,
	280, 181,
	281, 181,
	-2, 57,
-1, 611,
	280, 442,
	281, 442,
	-2, 60,
-1, 612,
	281, 443,
	-2, 61,
-1, 613,
	280, 446,
	281, 446,
	-2, 62,
-1, 614,
	280, 447,
	281, 447,
	-2, 63,
-1, 618,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 619,
	264, 509,
	265, 178,
	280, 210,
	284, 178,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 621,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 622,
	264, 509,
	265, 178,
	280, 210,
	281, 178,
	284, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 625,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 630,
	275, 170,
	363, 170,
	-2, 443,
-1, 631,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 632,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 639,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 658,
	264, 509,
	265, 178,
	277, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 680,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 682,
	279, 332,
	285, 332,
	-2, 210,
-1, 683,
	264, 509,
	265, 178,
	280, 210,
	281, 178,
	284, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 709,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 730,
	264, 509,
	265, 178,
	279, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 752,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 753,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 762,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 775,
	264, 509,
	265, 178,
	280, 210,
	285, 178,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 780,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 784,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 791,
	264, 509,
	265, 178,
	280, 210,
	284, 178,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 795,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 805,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 806,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 822,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 826,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 831,
	331, 501,
	-2, 235,
-1, 864,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 867,
	279, 88,
	-2, 89,
-1, 880,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 882,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 884,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 888,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 889,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 899,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 901,
	264, 509,
	265, 178,
	279, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 916,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 918,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 920,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 922,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 924,
	264, 509,
	265, 178,
	280, 210,
	284, 178,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 927,
	264, 509,
	265, 178,
	280, 210,
	284, 178,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 928,
	264, 509,
	265, 178,
	280, 210,
	284, 178,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 940,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	290, 210,
	-2, 178,
-1, 943,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 947,
	275, 174,
	363, 174,
	-2, 443,
-1, 948,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 949,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 986,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1014,
	264, 509,
	265, 178,
	279, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1015,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 1021,
	264, 509,
	265, 178,
	279, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1023,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1030,
	264, 509,
	265, 178,
	279, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1035,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1036,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1061,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1065,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1105,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1109,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1111,
	264, 509,
	265, 178,
	279, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1113,
	285, 278,
	-2, 277,
-1, 1114,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1120,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1121,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1122,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 1125,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 1127,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	284, 642,
	290, 210,
	-2, 178,
-1, 1132,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 1136,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1137,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 1138,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 1139,
	264, 509,
	265, 178,
	279, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1142,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1143,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1145,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1179,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1190,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 1191,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 1201,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1203,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1213,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1238,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1240,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1242,
	264, 509,
	265, 178,
	279, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1243,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1249,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1269,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	280, 210,
	290, 210,
	-2, 178,
-1, 1289,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1303,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1315,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1328,
	264, 509,
	265, 178,
	275, 178,
	280, 210,
	286, 178,
	290, 210,
	294, 178,
	-2, 515,
-1, 1357,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1365,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1368,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1370,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1372,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1374,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
-1, 1376,
	257, 515,
	261, 515,
	262, 515,
	263, 515,
	264, 509,
	-2, 210,
	};
# define YYNPROD 651
# define YYLAST 4551
static const yytabelem yyact[]={

   434,  1172,  1294,  1227,  1287,  1276,  1214,    14,    20,  1207,
   563,  1187,  1117,  1173,  1162,  1024,  1028,  1124,  1277,   230,
   395,  1123,    27,  1017,   865,    32,    35,    37,   886,   724,
    75,  1181,   895,   976,   971,   134,   802,   562,   972,   522,
   207,    75,   652,   723,   924,   430,   910,   181,   182,   400,
   671,   545,   672,    53,   571,   374,   894,   264,   892,   643,
   401,   739,   560,    52,   155,   350,   343,   489,    67,    51,
   623,   166,    60,   342,   745,    31,   299,   356,   226,   226,
   155,   206,   371,    60,   162,    66,   247,   249,   247,   249,
   252,   253,   315,   298,    10,    65,     9,   633,   243,   121,
   125,   370,   305,   357,   831,   212,   956,   119,   124,   120,
   123,   127,     7,   346,   360,   314,   122,   313,   242,   685,
  1074,   118,   126,   407,   355,   361,   359,   559,   687,   830,
   261,   134,   268,   289,   794,   316,   963,   292,   827,   311,
  1046,   306,   241,   647,   154,   297,   141,   551,   233,   234,
  1030,   315,     8,   358,   311,   315,   167,   168,   736,   205,
   311,   743,   310,   166,   309,   142,    19,    18,   166,   166,
   166,   799,   166,    55,   314,   200,   313,   310,   314,   309,
   313,   349,   312,   310,    55,   309,  1021,   244,    19,    18,
   255,   840,   375,   226,   316,   741,   757,   312,   316,    19,
    18,   192,   235,   312,   540,   260,   262,   755,   740,   397,
   397,   402,   402,   226,   758,   141,   324,   240,   226,   985,
   373,    22,   795,   418,   419,   226,   226,    25,    19,    18,
  1228,   399,   428,   372,   142,   444,   226,  1254,   367,   203,
   191,   304,   575,    92,   247,   268,   321,    98,   581,   396,
   398,   396,   404,    80,  1275,   461,   256,   101,    19,    18,
   668,   890,    80,   351,   184,   330,   268,  1364,   445,   669,
    81,  1114,   405,   337,   389,   340,    92,  1256,  1255,    81,
    98,   196,   540,   257,   258,    84,   100,    22,   541,   293,
   101,  1355,    93,  1083,    84,    95,    99,    19,    18,    94,
   136,   155,   575,   498,   268,   502,    19,    18,   259,   189,
   190,    22,   338,   666,   341,   427,   756,   389,   166,   100,
   166,   166,   166,   473,    39,    93,   426,   975,    95,    99,
   523,   393,    94,  1354,  1084,  1085,   447,   448,   449,   450,
    22,   413,   888,   542,    22,   546,   232,  1353,   421,   422,
   394,  1352,   388,    34,   501,   485,   295,    97,    96,    22,
   180,   486,   492,   268,   268,   268,   268,   653,   383,   375,
   375,   510,    22,    19,    18,   195,   121,   125,   521,   491,
    19,    18,   406,    15,   119,   124,   120,   123,   127,   490,
    97,    96,   805,   122,   494,   388,   680,    89,   118,   126,
    26,   550,    22,   621,  1351,   244,    28,  1349,   226,   622,
    82,   383,    85,    22,   226,    22,    22,   397,    22,    22,
   709,   603,   226,   226,   606,   612,   574,  1348,    81,    79,
    22,   602,   386,   601,   303,   487,    22,   599,    22,    86,
    88,   626,   460,    84,    89,   497,   630,    22,   634,   634,
   634,    22,   570,   157,   884,   640,   268,   396,    80,    85,
   622,   175,   683,   134,    87,   268,   268,  1224,   268,    22,
    22,   569,    22,    89,   379,   386,    79,   620,   459,   572,
   573,  1340,    24,    22,   268,  1317,    86,    88,    85,   389,
    84,   565,   566,   567,  1312,   389,   634,   634,    22,   580,
   582,  1022,   462,   389,   389,    79,   204,  1161,   131,   572,
   573,    87,   493,   627,   645,    86,    88,   379,    22,    84,
   166,  1310,  1308,   425,   644,   575,   166,   523,   166,   424,
  1282,   194,   166,   572,   573,   637,  1358,  1307,   654,    22,
    87,  1305,   674,   675,   727,   677,   635,   636,   661,   966,
   733,   268,   375,  1300,   662,   590,   670,   492,  1080,   967,
   969,  1081,   268,  1078,   693,    22,   711,   388,   378,  1298,
   424,  1297,   199,   388,   491,   968,   375,   268,  1222,   130,
    22,   388,   388,   383,   490,   131,   483,  1206,   502,   383,
   455,   612,   676,   678,   679,    22,    22,   383,   383,  1282,
    22,  1193,   131,  1166,   472,  1281,   470,   720,   686,   688,
   612,   378,    22,  1160,   721,   734,   746,   746,   202,   746,
  1350,  1091,  1090,   612,   751,   465,   468,   469,   663,  1072,
   747,   759,   749,   471,   737,  1087,   984,   717,   803,  1073,
   268,   722,   719,   226,   951,   731,   684,   386,   765,   689,
  1092,   938,   951,   386,   951,   620,   937,  1278,   983,   799,
   952,   386,   386,   777,   783,   841,   778,   473,   799,   832,
   799,   799,   775,   694,   801,   716,   800,   798,   803,   718,
   690,   268,   728,   502,   612,   638,   817,   700,   729,   379,
   288,   287,   283,   701,   697,   379,   809,   592,   166,   387,
   698,   166,   807,   379,   379,   829,   808,   591,   284,   523,
   268,   586,   585,   819,   838,   682,   472,   436,   470,   474,
   475,   681,   542,   820,   377,   587,   834,   837,   961,   546,
   583,   588,   843,   579,   578,    19,    18,   619,   468,   469,
   896,   577,   387,   531,   531,   471,   527,   896,   868,   536,
   530,   704,   528,   268,   268,   525,   912,   912,   912,   912,
   713,   524,   966,   715,   435,   382,   548,   377,   458,   651,
   226,   457,   967,   969,   226,   226,   519,   226,   226,   226,
   885,   268,   518,   378,   456,   300,   300,   812,   968,   378,
   906,   446,   301,   929,   453,   392,   947,   378,   378,    59,
   950,   391,   908,   909,   914,   900,   268,   268,   382,   390,
    59,   385,   911,   913,   911,   915,   927,   928,   354,   226,
   817,   817,   893,   268,   353,   352,   328,   268,   291,   893,
   939,    29,  1143,  1142,   166,  1076,   166,   166,   803,  1070,
   965,   201,   228,   228,   836,   835,   833,   234,   163,   270,
   817,   318,  1259,   166,   385,  1366,  1131,   166,  1130,  1230,
  1343,  1201,   817,  1023,  1230,   268,   916,   964,   897,   980,
   981,   523,   523,   994,   982,  1342,   864,   999,   958,  1230,
   989,   727,  1337,   244,  1012,   650,  1338,  1008,   959,   268,
   268,   912,   576,  1376,  1374,  1296,   269,   930,   931,  1191,
  1018,   934,   935,  1372,   705,  1267,   290,   649,   132,  1268,
  1005,  1006,  1011,   705,   387,    58,   705,   268,  1031,   268,
   387,   812,   812,   268,  1010,  1370,    58,   226,   387,   387,
  1265,   226,   226,   861,  1266,   226,   226,    57,  1368,   377,
   648,  1365,   957,  1121,   268,   377,  1260,  1019,    57,  1022,
  1261,   812,  1064,   377,   377,  1250,  1248,   228,   226,  1251,
  1249,   974,   270,   812,  1357,  1037,  1328,  1231,  1038,  1323,
    56,  1230,  1315,   228,   228,   403,   403,   228,  1289,  1285,
   382,    56,   228,   270,  1071,  1283,   382,   268,   646,   228,
   228,  1269,  1192,  1133,   382,   382,  1191,  1134,  1119,  1040,
   228,   817,  1120,  1022,  1089,  1075,   978,  1243,  1242,   269,
   979,  1103,   389,   389,  1240,   854,   389,   389,    50,   855,
  1238,   270,  1235,   912,   268,   810,   385,  1107,  1234,    50,
   269,  1213,   385,  1190,   384,   966,   268,   268,   706,   389,
   385,   385,   707,  1116,   538,   967,   969,   226,   537,   226,
  1279,   226,  1135,   226,   535,  1128,   397,  1179,   534,  1178,
   128,   968,  1167,  1147,   129,  1139,   268,  1138,   269,   503,
  1137,  1136,  1132,  1140,  1122,   882,  1155,   384,  1111,  1110,
   270,   270,   270,   270,   988,  1109,   705,   197,   992,  1159,
   388,   388,  1108,   998,   388,   388,   396,  1105,  1104,  1101,
   974,  1099,   812,  1007,  1096,  1009,   383,   383,  1022,   523,
   383,   383,  1035,  1175,  1176,   575,  1015,   388,  1180,  1002,
   997,   268,   268,   587,  1186,   738,   904,   269,   269,   269,
   269,  1018,  1018,   383,   903,  1208,   902,   268,   901,  1196,
   899,  1185,   614,  1197,  1194,  1195,   268,  1204,  1184,  1205,
  1216,   226,   923,   226,  1210,  1211,  1212,   898,   891,   933,
   883,   873,   871,   863,   856,   852,   752,   708,   166,   302,
   386,   386,   228,   270,   386,   386,  1223,   549,   228,   539,
   533,   228,   270,   270,   507,   270,   228,   228,   506,   613,
   505,   504,  1236,   454,   132,  1068,  1361,   386,  1360,  1359,
  1346,   270,   268,  1245,   268,  1344,  1163,  1164,  1165,  1336,
  1335,  1237,   379,   379,   268,  1334,   379,   379,  1333,  1331,
   269,   226,   288,   287,   327,  1330,  1329,  1102,  1327,   269,
   269,  1326,   269,   198,  1324,  1290,  1272,   705,   673,   379,
  1271,   705,  1262,   995,  1284,  1252,   705,   995,   269,   384,
   268,  1270,  1208,  1247,  1293,   384,   705,   995,   705,    22,
  1018,  1301,  1208,   384,   384,  1208,   193,  1208,   270,  1208,
  1291,  1306,  1292,  1299,  1309,   226,  1311,  1241,  1313,   270,
   380,  1316,  1239,  1319,  1233,  1321,  1314,  1220,  1183,  1169,
  1113,  1163,  1112,  1097,   270,  1225,   288,   287,   327,  1322,
  1039,  1003,  1001,    89,   268,   905,   378,   378,   614,  1051,
   378,   378,   511,   920,   881,   269,   268,   879,    85,   878,
   877,  1325,  1341,   380,   876,   875,   269,   614,  1345,   851,
   850,  1347,  1177,   378,   849,    79,   848,   847,   846,  1208,
   614,   269,   821,   793,  1274,    86,    88,   790,  1356,    84,
   463,   135,   503,  1339,  1280,   613,   389,   270,   268,  1098,
  1363,   472,  1095,   470,   308,   307,   268,   433,  1088,   268,
    87,   268,  1014,   268,   613,   268,   779,   268,   996,   993,
   705,   995,   619,   468,   469,   191,   889,   613,   880,   874,
   471,   872,   870,   862,   762,  1362,   311,   315,   270,   730,
   702,   614,  1229,  1367,   269,  1232,  1369,   228,  1371,   699,
  1373,   696,  1375,   816,  1377,   692,   288,   287,   327,   310,
   314,   309,   313,   625,   558,   977,   381,   270,   557,  1149,
   556,  1151,   442,  1153,   388,  1154,   555,   387,   387,   312,
   316,   387,   387,   554,   553,   269,   552,   503,   613,   543,
   383,   532,   288,   287,   327,   529,   526,   520,   417,   376,
   416,   415,   377,   377,   387,  1286,   377,   377,   325,   381,
   270,   270,   414,   412,   269,   411,   410,   409,   368,   282,
   995,   366,   345,   995,   995,   705,   329,   172,   995,   377,
   170,   157,   589,   584,   995,   380,   165,   365,   270,   267,
   364,   380,   376,   382,   382,   363,   362,   382,   382,   380,
   380,  1072,  1093,  1320,   386,   317,  1025,   269,   269,   140,
   245,  1073,   480,   270,   270,  1026,   479,   482,   481,   815,
   382,   477,   248,  1218,   228,  1219,   153,   478,   228,   228,
   270,   228,   228,   228,   270,   269,    33,   816,   816,   385,
   385,   814,   705,   385,   385,   705,   379,   472,   705,   470,
    83,    47,   995,   288,   287,   327,   544,   335,    45,    42,
   269,   269,   779,   921,    41,   484,   385,   816,   619,   468,
   469,   133,   270,   228,   813,    46,   471,   269,   323,   816,
    36,   269,   660,   332,   334,   336,    48,   336,    44,   138,
   642,   472,   150,   470,    43,    49,   270,   270,   250,   148,
   145,   227,   267,   179,   995,   144,   236,  1302,   705,  1288,
  1303,   251,   465,   468,   469,     5,   149,   177,    13,   269,
   471,   432,   811,   267,   270,     4,   270,   151,    12,   147,
   270,   381,   176,   326,   970,   146,   152,   381,     3,   667,
   378,    11,   665,   269,   269,   381,   381,  1253,   183,   296,
   178,   270,   185,   815,   815,   995,   705,   995,   238,   995,
  1174,   267,   695,   857,   376,   319,   320,  1171,   691,   744,
   376,   269,   748,   269,   750,   814,   814,   269,   376,   376,
   344,   228,   853,   815,   281,   228,   228,   278,   294,   228,
   228,    61,   705,    54,   270,   815,   173,  1288,   269,    40,
     6,   348,   347,   443,   246,   814,    30,    23,   813,   813,
    -1,    -1,   228,   725,   237,   239,  1082,   814,   816,   280,
   267,   267,   267,   267,   171,   169,   472,   331,   470,   339,
    71,   270,   995,   509,   164,   513,   515,   517,   813,    70,
   322,   269,  1202,   270,   270,  1203,    69,   465,   468,   469,
   813,   512,   508,   266,   451,   471,   811,   811,   472,   818,
   470,   254,   384,   384,    62,   439,   384,   384,  1263,   437,
   186,   387,  1264,   270,   628,   516,    68,   188,   269,   465,
   468,   469,   611,   187,   973,  1079,   811,   471,   326,   384,
   269,   269,   156,  1077,   369,   326,   377,   742,   811,  1100,
   859,   228,   514,   228,   496,   228,   495,   228,   139,   488,
   228,   137,    38,   267,    21,  1318,  1086,   472,  1168,   470,
   269,    -1,   267,   267,   839,   267,     2,   229,   270,   270,
   285,   277,   500,  1144,   815,    -1,  1145,   382,   465,   468,
   469,   267,    -1,    -1,   270,    -1,   471,   828,   472,   664,
   470,   333,    72,   270,    -1,   286,   814,   279,   158,   159,
   160,   161,   431,   866,   917,   441,   266,   918,   174,   465,
   468,   469,    16,    17,     1,   269,   269,   471,     0,     0,
     0,     0,     0,   385,     0,     0,   288,   287,   283,   813,
     0,   269,     0,     0,   275,   273,     0,     0,     0,     0,
   269,   472,   438,   470,   284,   228,     0,   228,   267,   270,
     0,   270,   658,   617,     0,   271,   272,   274,     0,   267,
     0,   270,   619,   468,   469,   266,   440,     0,     0,     0,
   471,    19,    18,   276,   267,   703,     0,   811,     0,     0,
     0,   710,     0,   712,     0,     0,     0,   714,   611,     0,
     0,     0,     0,     0,     0,     0,   269,   270,   269,     0,
   326,   326,   326,     0,   326,     0,     0,   611,   269,     0,
   288,   287,   283,     0,     0,   228,     0,     0,   275,   273,
   611,   326,     0,     0,   266,   266,   266,   266,   284,     0,
     0,     0,     0,     0,   265,     0,     0,   267,     0,   271,
   272,   274,     0,     0,   269,     0,     0,  1020,   380,   380,
     0,   270,   380,   380,  1027,    19,    18,   276,  1032,  1033,
  1034,     0,     0,   270,     0,     0,   288,   287,   283,   228,
     0,   472,     0,   470,     0,   380,     0,     0,   267,     0,
     0,   611,   438,     0,   284,     0,   610,   825,     0,     0,
   826,     0,   465,   468,   469,   474,   475,     0,   269,     0,
   471,     0,     0,     0,     0,   270,   440,   267,     0,     0,
   269,    19,    18,   270,     0,     0,   270,   266,   270,   472,
   270,   470,   270,     0,   270,     0,   266,   266,     0,   266,
     0,     0,     0,     0,     0,   466,     0,     0,   467,     0,
   465,   468,   469,     0,     0,   266,   384,   265,   471,     0,
   267,   267,   269,   858,     0,     0,   860,     0,     0,   472,
   269,   470,     0,   269,     0,   269,     0,   269,   472,   269,
   470,   269,     0,     0,     0,  1304,     0,     0,   267,     0,
   465,   468,   469,   326,  1273,     0,   326,     0,   471,   465,
   468,   469,     0,     0,   381,   381,     0,   471,   381,   381,
     0,     0,     0,   267,   267,     0,   265,     0,     0,     0,
     0,     0,   266,     0,   472,     0,   470,   867,  1029,     0,
   267,   381,     0,   266,   267,     0,     0,   376,   376,     0,
     0,   376,   376,   791,     0,   619,   468,   469,   266,     0,
     0,     0,     0,  1199,     0,     0,     0,     0,     0,     0,
     0,     0,   610,   472,   376,   470,     0,     0,     0,     0,
     0,     0,   267,  1244,   618,   265,   265,   265,   265,     0,
     0,   232,     0,     0,   619,   468,   469,   233,   234,     0,
   785,     0,   471,     0,   610,     0,   267,   267,     0,     0,
   223,     0,     0,   231,     0,     0,     0,     0,    19,    18,
     0,   266,     0,   208,   224,     0,     0,     0,   987,   214,
   216,   215,   991,   209,   267,     0,   267,   222,     0,     0,
   267,     0,  1067,     0,     0,     0,     0,   609,     0,     0,
   220,   210,   217,   225,   472,     0,   470,     0,   213,     0,
     0,   267,   266,     0,     0,   610,     0,     0,     0,     0,
  1221,     0,     0,     0,     0,   465,   468,   469,   265,     0,
     0,     0,     0,   471,     0,   990,     0,   265,   265,     0,
   265,   266,     0,   288,   287,   283,   211,   218,   472,     0,
   470,   275,   273,     0,   267,     0,   265,     0,   472,   438,
   470,   284,   380,     0,  1170,     0,     0,     0,  1115,   465,
   468,   469,   271,   272,   274,     0,     0,   471,   221,   619,
   468,   469,   219,   440,   266,   266,     0,   471,    19,    18,
   276,   267,     0,     0,     0,     0,     0,     0,     0,   288,
   287,   283,     0,   267,   267,     0,     0,   275,   273,     0,
     0,     0,   266,     0,     0,   438,     0,   284,     0,     0,
     0,   429,     0,   265,     0,     0,     0,     0,   271,   272,
   274,     0,     0,   267,   265,     0,     0,   266,   266,   440,
     0,     0,   949,     0,    19,    18,   276,     0,   472,   265,
   470,     0,     0,     0,   266,   948,     0,     0,   266,   990,
  1048,     0,     0,   609,  1156,     0,     0,  1054,     0,   465,
   468,   469,     0,   476,     0,     0,     0,   471,     0,     0,
     0,     0,   990,     0,     0,   288,   287,   283,   267,   267,
     0,   784,     0,   275,   273,   609,   266,     0,   464,     0,
     0,   438,     0,   284,   267,     0,     0,     0,   381,     0,
     0,     0,   265,   267,   271,   272,   274,   472,     0,   470,
   266,   266,     0,     0,     0,   440,     0,     0,     0,     0,
    19,    18,   276,     0,   547,     0,  1150,     0,   619,   468,
   469,   376,     0,   288,   287,   283,   471,     0,   266,     0,
   266,   275,   273,   265,   266,   568,   609,     0,     0,   438,
     0,   284,     0,     0,     0,     0,     0,     0,     0,   267,
     0,   267,   271,   272,  1127,   266,     0,     0,     0,     0,
     0,   267,   265,   440,   632,     0,     0,     0,    19,    18,
   276,     0,     0,  1226,     0,     0,     0,   631,   593,   594,
   595,   596,     0,   597,   598,     0,   600,     0,     0,     0,
     0,     0,     0,   607,   615,     0,   616,   267,   266,   472,
     0,   470,     0,     0,     0,   265,   265,   624,   288,   287,
   283,   624,     0,     0,   629,  1148,   275,   273,     0,     0,
   465,   468,   469,   472,   561,   470,   284,     0,   471,     0,
     0,     0,     0,   265,     0,   266,     0,   271,   272,   274,
     0,     0,   564,  1055,   619,   468,   469,   266,   266,     0,
     0,   267,   471,    19,    18,   276,     0,     0,   265,   265,
     0,     0,     0,   267,   288,   287,   283,   464,   472,     0,
   470,     0,   275,   273,     0,   265,     0,   266,     0,   265,
   438,     0,   284,     0,  1146,     0,     0,     0,     0,   465,
   468,   469,     0,   271,   272,   274,     0,   471,     0,     0,
     0,     0,     0,     0,   440,   267,   472,     0,   470,    19,
    18,   276,   726,   267,   464,     0,   267,   265,   267,     0,
   267,     0,   267,     0,   267,   926,     0,   619,   468,   469,
     0,     0,   266,   266,     0,   471,   288,   287,   283,     0,
     0,   265,   265,     0,   275,   273,     0,     0,   266,   761,
     0,   763,   438,   764,   284,     0,     0,   266,   766,   767,
     0,     0,     0,     0,     0,   271,   272,   274,     0,   265,
     0,   265,     0,     0,   263,   265,   440,     0,     0,   464,
     0,    19,    18,   276,     0,     0,     0,   472,   786,   470,
   787,   788,     0,     0,   792,     0,   265,  1048,     0,     0,
   796,   797,     0,  1106,  1053,     0,     0,     0,   465,   468,
   469,     0,     0,   266,     0,   266,   471,     0,     0,     0,
     0,     0,     0,   464,   472,   266,   470,   824,     0,     0,
     0,     0,     0,   288,   287,   283,   472,     0,   470,   265,
  1069,   275,   273,     0,     0,   465,   468,   469,     0,   438,
     0,   284,   844,   471,     0,  1065,   464,   465,   468,   469,
     0,   266,   271,   272,   274,   471,     0,     0,     0,     0,
   464,   464,   464,   440,   464,   472,   265,   470,    19,    18,
   276,     0,     0,     0,   472,     0,   470,   452,   265,   265,
     0,  1066,     0,     0,  1048,     0,   465,   468,   469,   887,
   472,  1049,   470,  1061,   471,   619,   468,   469,     0,     0,
     0,     0,     0,   471,     0,   266,  1058,     0,   265,     0,
     0,   465,   468,   469,     0,     0,   472,   266,   470,   471,
     0,   919,     0,     0,     0,     0,   472,     0,   470,   925,
   925,   925,     0,     0,   932,  1050,   499,   619,   468,   469,
   464,     0,  1004,     0,     0,   471,     0,   465,   468,   469,
   944,     0,     0,     0,   946,   471,     0,     0,     0,   266,
     0,     0,     0,   265,   265,   464,     0,   266,     0,     0,
   266,     0,   266,   464,   266,     0,   266,     0,   266,   265,
     0,   288,   287,   283,     0,   472,     0,   470,   265,   275,
   273,     0,     0,     0,   464,  1043,   472,  1125,   470,   284,
     0,   472,     0,   470,     0,     0,   619,   468,   469,   464,
   271,   272,  1127,     0,   471,  1036,     0,   465,   468,   469,
   986,   440,   465,   468,   469,   471,    19,    18,   276,     0,
   471,     0,   472,     0,   470,     0,     0,     0,     0,   726,
     0,   726,     0,  1013,   265,     0,   265,   464,   921,   472,
   464,   470,     0,   619,   468,   469,   265,   608,     0,     0,
     0,   471,     0,     0,     0,   953,     0,     0,     0,     0,
   465,   468,   469,     0,   464,     0,     0,     0,   471,  1044,
   472,     0,   470,  1047,     0,     0,  1047,  1047,   641,     0,
   945,     0,   265,     0,     0,     0,     0,   655,   656,  1059,
   657,   619,   468,   469,   472,     0,   470,  1062,  1063,   471,
     0,     0,   464,   472,     0,   470,   659,     0,     0,     0,
     0,     0,   472,   943,   470,   465,   468,   469,     0,   942,
     0,     0,   941,   471,   619,   468,   469,     0,     0,     0,
     0,   464,   471,   619,   468,   469,   265,   472,     0,   470,
     0,   471,     0,     0,     0,     0,     0,     0,   265,   464,
   464,     0,     0,     0,     0,   464,   940,   464,   619,   468,
   469,     0,     0,   887,  1118,   472,   471,   470,     0,     0,
  1126,     0,     0,   735,     0,     0,     0,     0,     0,  1126,
     0,     0,     0,     0,   922,     0,   465,   468,   469,     0,
   265,     0,     0,     0,   471,   464,     0,     0,   265,   760,
   472,   265,   470,   265,     0,   265,     0,   265,     0,   265,
  1157,   464,   472,   768,   470,     0,   823,     0,     0,     0,
     0,   465,   468,   469,     0,     0,     0,     0,   472,   471,
   470,   822,     0,   465,   468,   469,   464,   464,     0,     0,
   464,   471,     0,     0,     0,   789,   472,   806,   470,   465,
   468,   469,     0,     0,  1182,   464,     0,   471,  1182,     0,
  1188,     0,   804,  1189,   472,   791,   470,   619,   468,   469,
     0,     0,     0,     0,  1198,   471,  1200,     0,   472,     0,
   470,     0,     0,   780,     0,   465,   468,   469,   782,   464,
     0,  1215,  1215,   471,   472,     0,   470,     0,     0,   619,
   468,   469,     0,   842,   781,     0,   845,   471,   472,     0,
   470,     0,     0,     0,     0,   619,   468,   469,   776,     0,
     0,     0,     0,   471,   464,     0,     0,     0,  1182,   619,
   468,   469,   869,     0,     0,   232,   464,   471,     0,  1118,
  1246,   233,   234,     0,   408,     0,     0,     0,     0,   472,
     0,   470,     0,   464,   223,     0,     0,   231,     0,   774,
     0,     0,    19,    18,     0,     0,     0,   208,   224,     0,
   619,   468,   469,   214,   216,   215,   907,   209,   471,     0,
     0,   222,     0,     0,     0,     0,     0,  1182,   472,  1182,
   470,  1188,  1295,    89,   220,   210,   217,   225,   773,     0,
     0,     0,   213,   936,   464,     0,    82,     0,    85,   619,
   468,   469,   464,     0,     0,     0,     0,   471,     0,     0,
     0,   472,     0,   470,    81,    79,     0,     0,   954,   955,
     0,   772,     0,     0,     0,    86,    88,     0,  1182,    84,
   211,   218,   619,   468,   469,   960,     0,     0,     0,   962,
   471,     0,   464,   464,     0,     0,   232,     0,     0,     0,
    87,     0,   233,   234,  1152,   408,     0,     0,     0,     0,
     0,     0,   221,     0,     0,   223,   219,  1295,   231,     0,
     0,     0,     0,    19,    18,     0,     0,  1000,   208,   224,
     0,   472,     0,   470,   214,   216,   215,     0,   209,     0,
     0,   771,   222,     0,     0,     0,     0,     0,     0,     0,
     0,  1016,   619,   468,   469,   220,   210,   217,   225,     0,
   471,     0,     0,   213,     0,     0,   472,   464,   470,     0,
   472,     0,   470,     0,     0,   472,   770,   470,     0,  1041,
   769,  1042,     0,     0,     0,  1045,     0,   619,   468,   469,
     0,   619,   468,   469,   753,   471,   465,   468,   469,   471,
     0,   211,   218,     0,   471,     0,  1060,    19,    18,     0,
    78,    92,    64,     0,     0,    98,   102,   103,   472,     0,
   470,   116,     0,     0,    63,   101,     0,     0,   754,     0,
     0,     0,   143,   221,     0,     0,     0,   219,    89,   619,
   468,   469,     0,    91,     0,     0,     0,   471,     0,  1094,
    77,    82,    80,    85,   100,     0,     0,     0,     0,     0,
    93,     0,   106,    95,    99,   104,   105,    94,     0,    81,
    79,     0,     0,   107,     0,     0,     0,     0,    74,    73,
    86,    88,   117,     0,    84,     0,  1129,   108,   109,   111,
   115,   114,     0,   472,     0,   470,     0,    76,   472,  1141,
   470,   121,   125,   732,    90,    87,   110,   112,   113,   119,
   124,   120,   123,   127,   619,   468,   469,   639,   122,   465,
   468,   469,   471,   118,   126,    97,    96,   471,  1158,    19,
    18,     0,    78,    92,    64,     0,     0,    98,   102,   103,
   472,     0,   470,   116,     0,     0,    63,   101,     0,     0,
     0,     0,   617,     0,     0,     0,     0,     0,     0,     0,
    89,   619,   468,   469,     0,    91,     0,     0,     0,   471,
     0,     0,    77,    82,    80,    85,   100,     0,     0,     0,
     0,     0,    93,     0,   106,    95,    99,   104,   105,    94,
     0,    81,    79,     0,     0,   107,     0,     0,     0,  1209,
    74,    73,    86,    88,   117,     0,    84,     0,  1217,   108,
   109,   111,   115,   114,     0,   472,     0,   470,     0,    76,
     0,     0,     0,   121,   125,     0,    90,    87,   110,   112,
   113,   119,   124,   120,   123,   127,   465,   468,   469,     0,
   122,     0,     0,   232,   471,   118,   126,    97,    96,   233,
   234,   472,     0,   470,     0,     0,     0,     0,     0,     0,
     0,     0,   223,     0,  1257,   231,  1258,     0,     0,     0,
    19,    18,   619,   468,   469,   208,   224,     0,     0,     0,
  1199,   214,   216,   215,     0,   209,     0,     0,     0,   222,
     0,     0,   232,     0,     0,     0,     0,     0,   233,   234,
     0,    89,   220,   210,   217,   225,     0,     0,     0,     0,
   213,   223,     0,     0,   231,    80,    85,     0,     0,    19,
    18,     0,     0,     0,   208,   224,     0,     0,     0,     0,
   214,   216,   215,    79,   209,     0,     0,     0,   222,     0,
     0,     0,     0,    86,    88,     0,     0,    84,   211,   218,
    89,   220,   210,   217,   225,     0,     0,     0,     0,   213,
     0,     0,     0,     0,     0,    85,  1332,     0,    87,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
   221,   232,    79,     0,   219,     0,     0,   233,   234,  1052,
   408,     0,    86,    88,     0,     0,    84,   211,   218,     0,
   223,     0,     0,   231,     0,     0,     0,     0,    19,    18,
     0,     0,     0,   208,   224,     0,     0,    87,     0,   214,
   216,   215,     0,   209,     0,     0,     0,   222,     0,   221,
   232,     0,     0,   219,     0,     0,   233,   234,     0,   408,
   220,   210,   217,   225,     0,     0,     0,     0,   213,   223,
     0,     0,   231,     0,     0,     0,     0,    19,    18,     0,
     0,     0,   208,   224,     0,     0,     0,     0,   214,   216,
   215,     0,   209,     0,     0,     0,   222,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   211,   218,   232,   220,
   210,   217,   225,     0,   233,   234,     0,   213,     0,     0,
     0,     0,     0,     0,     0,     0,     0,   223,     0,     0,
   231,     0,     0,     0,     0,    19,    18,     0,   221,     0,
   208,   224,   219,     0,     0,     0,   214,   216,   215,     0,
   209,     0,     0,     0,   222,   211,   218,   232,     0,     0,
     0,     0,     0,   233,   234,     0,     0,   220,   210,   217,
   225,     0,     0,     0,     0,   213,   223,     0,     0,   231,
     0,     0,     0,  1057,    19,    18,     0,   221,     0,   208,
   224,   219,     0,     0,     0,   214,   216,   215,     0,   209,
     0,     0,     0,   222,     0,     0,  1056,     0,     0,     0,
     0,     0,     0,   211,   218,   232,   220,   210,   217,   225,
     0,   233,   234,     0,   213,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   223,     0,     0,   231,     0,     0,
     0,     0,    19,    18,     0,   221,     0,   208,   224,   219,
     0,     0,     0,   214,   216,   215,     0,   209,     0,     0,
     0,   222,   211,   218,   232,     0,     0,     0,     0,     0,
   233,   234,     0,     0,   220,   210,   217,   225,     0,     0,
     0,     0,   213,   223,     0,     0,   231,     0,     0,     0,
   605,    19,    18,     0,   221,     0,   208,   224,   219,     0,
     0,     0,   214,   216,   215,     0,   209,     0,     0,     0,
   222,     0,     0,   604,     0,     0,     0,     0,     0,     0,
   211,   218,   232,   220,   210,   217,   225,     0,   233,   234,
   423,   213,     0,     0,     0,     0,     0,     0,     0,     0,
     0,   223,     0,     0,   231,     0,     0,     0,     0,    19,
    18,     0,   221,     0,   208,   224,   219,     0,     0,     0,
   214,   216,   215,     0,   209,     0,     0,     0,   222,   211,
   218,   232,     0,     0,     0,     0,     0,   233,   234,   420,
     0,   220,   210,   217,   225,     0,     0,     0,     0,   213,
   223,     0,     0,   231,     0,     0,     0,     0,    19,    18,
     0,   221,     0,   208,   224,   219,     0,     0,     0,   214,
   216,   215,     0,   209,     0,     0,     0,   222,     0,     0,
     0,     0,     0,     0,     0,     0,     0,   211,   218,   232,
   220,   210,   217,   225,     0,   233,   234,     0,   213,     0,
     0,     0,     0,     0,     0,     0,     0,     0,   223,     0,
     0,   231,     0,     0,     0,     0,    19,    18,     0,   221,
     0,   208,   224,   219,     0,     0,     0,   214,   216,   215,
     0,   209,     0,     0,     0,   222,   211,   218,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,   220,   210,
   217,   225,     0,     0,     0,     0,   213,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,   221,     0,
     0,     0,   219,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   211,   218,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   221,     0,     0,     0,
   219 };
static const yytabelem yypact[]={

  -259,-10000000,  -259,-10000000,-10000000,-10000000,   -45,   -45,-10000000,-10000000,
-10000000,-10000000,-10000000,-10000000,   208,   -63,-10000000,-10000000,-10000000,-10000000,
   126,   -45,   -45,   546,    77,   -45,   -45,    50,-10000000,  3426,
   785,-10000000,   305,   915,   -45,   -69,  1076,    21,  -298,  -199,
  3304,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,
-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,
-10000000,-10000000,-10000000,   -45,  1217,  1217,  1217,  1217,  1217,   566,
   -45,   566,   566,  1216,  1213,   179,   -34,  4133,  4133,   -45,
-10000000,-10000000,-10000000,  -270,   603,   -45,   -45,   -45,   -45,   -45,
   -45,   -93,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,
-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,
-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,
-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,    77,
    77,  1722,   -45,   629,   322,   543,   -45,   -21,  -270,  -130,
-10000000,  -326,  -343,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,
-10000000,-10000000,-10000000,   507,   890,   161,   566,  1024,   569,   569,
   569,   566,   -45,  1194,   541,  1212,   125,   -45,   -45,   -45,
  -218,   -45,  -218,-10000000,   569,  1208,  -217,-10000000,-10000000,-10000000,
  -104,   540,   539,   533,  -265,  1233,  1232,  1227,  1224,  1207,
  1204,  -137,  4133,   524,   516,   510,-10000000,-10000000,-10000000,-10000000,
-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,    58,    70,    70,
    70,    70,  3754,  1203,  1202,  1201,  1199,  4133,  1198,  1187,
  1186,  1184,   -45,   -45,  4075,  4026,   249,    41,-10000000,-10000000,
-10000000,   -45,  1638,  1158,    -6,  4133,   506,   603,   603,   603,
   603,-10000000,-10000000,   -45,  1722,   509,   914,   310,   499,   -69,
   486,   483,   193,   157,   -45,-10000000,-10000000,-10000000,-10000000,-10000000,
-10000000,   228,  1075,  1824,-10000000,   432,-10000000,-10000000,   -69,-10000000,
-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,
-10000000,-10000000,-10000000,-10000000,  1638,  1273,  1265,-10000000,-10000000,   306,
-10000000,   -95,   -69,   -31,  -270,   603,-10000000,-10000000,-10000000,-10000000,
   -45,-10000000,   -45,  1722,    70,   912,   911,   909,   905,-10000000,
-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,   -45,  1038,   -45,
   -45,   -45,   497,  1183,-10000000,  1305,-10000000,-10000000,-10000000,   -45,
-10000000,   476,  1182,   467,  1181,   465,  1177,   901,   779,   464,
   769,   900,     3,  1175,   -45,  1638,-10000000,   481,   898,   128,
-10000000,  -151,-10000000,-10000000,-10000000,  1172,  1170,  1169,  1162,  1156,
  1154,  1150,  2370,  2370,  2370,  2370,  1638,-10000000,   -45,   -45,
   192,   246,-10000000,-10000000,   612,   -69,   456,   449,   448,-10000000,
-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,
-10000000,-10000000,-10000000,  -134,  -134,   445,  1220,   290,   427,   426,
   446,  1219,   275,-10000000,   422,   412,-10000000,  4133,-10000000,  1638,
  1638,  1638,  1638,  4133,  1638,  1638,    70,  1638,   148,   146,
   -45,  3968,  3919,   -45,  1638,  1638,-10000000,  1638,   -69,  3475,
-10000000,  1778,-10000000,-10000000,   129,-10000000,-10000000,-10000000,  1638,  1149,
   -45,-10000000,  1638,-10000000,   -69,  2227,-10000000,   -45,   -45,   -45,
   566,   400,  3433,-10000000,   -45,  1722,-10000000,-10000000,-10000000,-10000000,
    63,    82,    77,-10000000,  1722,  1722,-10000000,  1722,-10000000,-10000000,
-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,  1646,-10000000,-10000000,-10000000,
-10000000,-10000000,-10000000,  1722,   -86,-10000000,-10000000,-10000000,   -64,-10000000,
   964,   964,   964,   603,   964,   -45,   -45,   890,   123,  3550,
   436,   844,   182,-10000000,  -222,  -212,  -233,  -281,   395,  1141,
-10000000,  1305,   388,  1137,   415,  1135,   408,  1126,-10000000,   -45,
   -45,   763,   888,   140,-10000000,   -45,   -45,   -45,-10000000,   -45,
-10000000,   -45,   -45,  -281,  -233,-10000000,-10000000,  -281,-10000000,  -233,
-10000000,-10000000,   125,  1638,   403,  1125,   125,  3428,-10000000,  -104,
  1722,  -115,  -162,  -162,  -162,  -162,  -162,  -162,  -162,-10000000,
-10000000,  1722,   887,-10000000,  3310,-10000000,-10000000,-10000000,  3353,   -89,
    23,  -100,-10000000,-10000000,   -79,   -45,  1722,-10000000,-10000000,-10000000,
  1638,  1120,  1638,-10000000,  1638,-10000000,-10000000,    70,-10000000,  1638,
  1638,-10000000,-10000000,  3305,  3301,  3266,  3196,  3163,  3124,   387,
  3083,-10000000,-10000000,   969,-10000000,-10000000,   969,  1096,  3039,  1778,
-10000000,-10000000,   129,-10000000,-10000000,  3069,  3053,-10000000,  1638,  1638,
-10000000,  1638,  1638,  1072,  3021,  1638,   -69,  1068,  -141,  2461,
   129,  1638,  1638,   392,   -69,   391,   389,   -45,-10000000,  1722,
   112,  3003,  3099,   139,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,
-10000000,-10000000,-10000000,   110,  1067,  3550,  2987,  2975,  1638,  1776,
  -191,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,  -295,   -45,-10000000,
-10000000,   562,-10000000,  1305,   561,   560,   964,   -45,  -108,   380,
  1722,-10000000,    70,  1638,  1063,  1062,  1061,  1059,  1055,  1054,
-10000000,   886,-10000000,   740,-10000000,   885,-10000000,   -45,-10000000,-10000000,
   -45,-10000000,   -45,  1119,   884,   596,-10000000,  1305,   -45,  1722,
  1118,   883,  1117,   882,  1115,  1050,  1049,  1045,  1044,  1042,
  1114,   -75,-10000000,  1039,   796,   881,  2461,   180,   -45,-10000000,
  1638,-10000000,-10000000,    69,-10000000,  3550,  1112,   -37,   879,   -45,
-10000000,-10000000,-10000000,   588,   878,   861,   -45,   859,   857,   855,
   847,  1030,  1722,  1722,  1111,   -45,   -45,   -45,   -45,   586,
  1593,  2461,  1638,  2461,  2461,  1040,  2461,  1292,  2940,  3754,
  2426,  2426,  2426,  4133,  4133,  1638,  3754,  3616,  3616,-10000000,
  1722,   371,   366,-10000000,  1778,-10000000,  2912,  2887,  2878,  2869,
-10000000,  1638,  2845,-10000000,-10000000,  2085,  2461,  2461,-10000000,   -45,
-10000000,-10000000,   375,   -69,  2814,  1722,  1722,   139,-10000000,-10000000,
  -226,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,  3567,   139,
-10000000,-10000000,  1722,-10000000,   451,-10000000,  1722,-10000000,  -195,   556,
   502,-10000000,    54,   -45,   731,   -45,   -45,   -45,   373,   351,
   -72,-10000000,  3550,   844,  2797,  2766,-10000000,-10000000,-10000000,-10000000,
-10000000,-10000000,   -45,   -45,-10000000,  1305,   -45,   -45,  1105,   -45,
  1104,   841,   -45,   -45,  1722,  1027,   840,-10000000,  1026,  2691,
   -45,   -45,   -45,   -45,   -45,-10000000,-10000000,-10000000,-10000000,-10000000,
  1638,-10000000,  1638,   -45,  1638,  1098,   837,  2461,  1722,  1722,
   -45,  -162,  -111,   836,   829,   583,   -69,  1257,  -162,  1638,
  -147,  1638,  -162,  -162,  -162,-10000000,   833,  2761,-10000000,-10000000,
   192,   829,   -69,   222,  1025,   724,  1722,-10000000,  1722,  2750,
  1638,-10000000,  1722,  -184,  2595,  2681,  3705,  2498,  2141,-10000000,
  4133,  4133,  2378,-10000000,  3861,  3812,  2655,-10000000,-10000000,-10000000,
  1638,-10000000,-10000000,  1722,  2639,-10000000,  2461,   129,  1638,  1638,
   -69,   -45,-10000000,-10000000,  2591,  2630,-10000000,  1965,   139,-10000000,
  3550,   918,  2579,-10000000,   555,  1251,-10000000,-10000000,-10000000,-10000000,
  -211,   551,-10000000,-10000000,   289,    33,   350,  1094,-10000000,  1305,
   337,   336,   365,-10000000,-10000000,  1252,  1722,  1088,   825,  1018,
-10000000,  1085,   822,-10000000,   820,-10000000,   -45,   -45,   819,   818,
  2542,-10000000,  1305,-10000000,-10000000,   813,   806,   800,   799,  1017,
  1015,   796,    -3,  2093,  1638,  1638,  3550,   723,-10000000,   670,
   795,  2753,   -45,  1722,   577,-10000000,-10000000,   793,   718,  2461,
  2753,   792,   791,   788,   786,  1722,  1722,   549,   548,-10000000,
-10000000,  1562,  2423,   564,  2461,  2354,  3754,  2252,  3220,-10000000,
  3754,-10000000,  3754,-10000000,-10000000,    70,-10000000,-10000000,-10000000,  2461,
  2183,  1638,  2461,  2461,   -69,  1722,-10000000,-10000000,-10000000,-10000000,
  1251,   328,-10000000,-10000000,-10000000,   223,-10000000,-10000000,-10000000,-10000000,
-10000000,-10000000,   318,-10000000,-10000000,-10000000,   783,-10000000,-10000000,  1014,
-10000000,-10000000,-10000000,-10000000,  2083,-10000000,   -45,-10000000,-10000000,   -45,
   -45,   -45,   780,   778,   -45,  1638,-10000000,  1013,   -45,  1638,
   -45,  1638,-10000000,-10000000,  1638,-10000000,   754,   717,  2461,   316,
  1722,  1722,  1638,-10000000,-10000000,  2285,  3586,  1638,   581,  1471,
-10000000,  1257,  1638,   302,   -45,-10000000,  1722,  1638,  1638,  1638,
   752,  3550,  1638,  1638,-10000000,  1722,-10000000,-10000000,-10000000,-10000000,
  3754,-10000000,  3754,-10000000,-10000000,  1012,-10000000,  2461,  2039,   293,
-10000000,-10000000,   183,   502,   502,   502,-10000000,   -45,   -45,-10000000,
-10000000,   -45,   692,-10000000,   -45,  1009,   749,   743,   -45,  1638,
   741,  1007,  2461,-10000000,   735,  1002,   729,   728,  2461,  1958,
  1638,  1638,-10000000,-10000000,   978,   681,   680,   970,  1919,   -23,
  2461,  1722,-10000000,  1722,   571,   671,-10000000,   967,   -69,  1503,
   655,   630,   712,  1722,   965,  2461,   961,  1873,-10000000,-10000000,
  4133,-10000000,-10000000,   -30,   369,   775,  1080,   320,-10000000,   706,
   -45,-10000000,   700,-10000000,   -45,   -45,   699,   960,  1638,-10000000,
  1638,-10000000,  1638,  1638,-10000000,   620,  2461,   286,   284,  1722,
   268,   -45,-10000000,-10000000,-10000000,-10000000,-10000000,  1336,  1864,-10000000,
   256,   -45,   252,   237,   -45,   236,   -45,   209,   -45,  1638,
   693,-10000000,-10000000,-10000000,  4133,   369,   200,-10000000,-10000000,-10000000,
-10000000,   -45,   -45,   -45,-10000000,   -45,   690,   959,-10000000,  1638,
-10000000,   956,   953,   687,   951,  2461,-10000000,-10000000,-10000000,   950,
-10000000,   944,-10000000,  1722,-10000000,-10000000,   943,-10000000,-10000000,   940,
-10000000,   935,-10000000,   934,   607,  1722,   196,-10000000,   -45,   600,
-10000000,   585,   930,   -45,-10000000,   925,-10000000,-10000000,  1638,-10000000,
   142,   122,   339,   119,    66,    62,    48,     6,   -45,   685,
-10000000,   251,-10000000,-10000000,-10000000,   924,-10000000,   923,-10000000,-10000000,
-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,   921,  1722,   -45,-10000000,
-10000000,   -18,   662,   580,-10000000,  1722,-10000000,   659,  1722,   646,
  1722,   624,  1722,   615,  1722,   614,  1722,-10000000 };
static const yytabelem yypgo[]={

     0,  1884,     0,   383,  1883,  1882,  1875,    52,  1873,    24,
  1479,  1605,   123,  1867,  1865,  2234,  1266,    40,   105,  2188,
    59,   988,   143,   940,   907,   885,   769,    42,    44,   382,
  1233,  1864,  1862,  1861,  1425,   230,    13,    11,     2,  1859,
  1857,    38,    18,  1855,  1853,  1852,  1845,   764,  1087,  2662,
    57,  1872,  1631,    10,  1367,   717,  1604,  1802,    84,  1842,
    74,    61,    58,    21,    14,   129,     6,  1841,  1840,  1515,
  1837,    70,    19,  1836,  1648,  1635,  1625,  1834,    50,  1831,
    33,  1828,     3,     1,  1826,  1825,    67,    95,    85,    68,
  1824,  1822,  1821,  1819,  1560,   217,    98,    36,  1818,  1519,
  1816,    97,  1814,  1812,  1810,     4,  1809,   841,   102,   141,
  1807,    15,  1804,  1803,  1795,  1794,    48,  1793,   127,  1787,
  1786,  1785,    31,  1784,   618,    45,   101,    46,    54,  1780,
  1779,  1775,  1774,  1771,  1769,    69,  1598,  1762,  1761,  1756,
  1750,  1749,  1744,  1740,  1737,  1735,  1567,  1734,  1729,  1596,
  1726,    53,  1725,    39,  1724,    55,    12,  1520,    23,    43,
    29,  1723,    49,  1721,  1720,  1536,   144,    62,    37,    82,
    56,  1717,  1716,  1532,  1714,  1712,  1711,   572,    20,  1710,
  1709,    73,    66,  1585,  1706,  1574,  1569,  1568,  1561,    63,
  1703,  1701,    51,    60,     5,   531,     9,  1697,  1694,  1692,
  1678,  1677,  1673,  1672,  1670,  1668,    32,    28,  1662,   506,
  1660,    47,  1658,    75,  1546,   375,   281,    65,  1657,    17,
  1652,  1649,  1644,    34,   239,  1642,  1627,  1613,   175,   159,
    81,  1611,  1125,    16,  1600,  1592,  1590,  1575,  1566 };
static const yytabelem yyr1[]={

     0,    11,    13,    15,    15,    15,    15,    15,    16,    20,
    20,    20,    20,    20,    20,    20,    20,    20,    20,    20,
    20,    20,    20,    20,    28,    28,    28,    28,    28,    28,
    28,    30,    30,    30,    31,    31,    31,    31,    32,    32,
    33,    33,    33,    39,    40,    40,    40,    43,    43,    46,
    47,    48,    48,    49,    49,    49,    49,    49,    53,    53,
    50,    50,    50,    50,    56,    60,    60,    64,    66,    67,
    67,    69,    69,    69,    69,    58,    58,    58,    58,    58,
    70,    70,    18,    18,    18,    18,     6,     7,     8,     9,
    73,    73,    73,    73,    73,    73,    73,    77,    77,    78,
    78,    78,    78,    79,    79,    79,    79,    79,    81,    80,
    84,    85,    80,    86,    86,    86,    90,    76,    93,    93,
    92,    92,    92,    98,    98,   100,    99,   102,    99,    89,
   104,   103,   106,   103,   105,   107,    57,    57,    57,    57,
    57,    57,    57,   110,   110,   111,   111,   112,   112,   112,
   113,   113,   115,   116,   116,   114,   114,   120,   120,   120,
   120,   121,   121,   121,   122,     4,    72,    72,    27,   123,
   123,   123,   123,   123,   123,   123,   123,   124,    19,    19,
    19,    19,    19,    19,    19,    19,    19,    19,   119,   129,
   130,   130,   130,   132,   134,   134,   134,   134,   134,   136,
   136,   136,   136,   136,   136,   136,   136,   136,   136,   148,
     2,     2,     2,     2,     3,     3,   149,   150,   150,   150,
   152,   151,   153,   153,   154,   135,   155,   156,   156,   156,
    36,    83,    83,    23,    41,    65,    65,    65,    65,    65,
   158,    91,    91,   159,   159,   159,    59,    59,   163,   163,
    97,    97,   165,   165,   167,   167,   167,   167,   167,   126,
   127,   171,   171,   101,   101,   173,   157,   175,    45,   177,
   177,   177,   177,    71,    71,    74,   181,   181,   181,   183,
   180,   180,   180,   180,   180,   180,   180,   180,   180,   180,
   180,   180,   180,   180,   180,   180,   180,   180,   180,   185,
   185,   185,   185,   185,   185,   185,   185,   185,   185,   185,
   185,   185,   179,   179,   139,   139,   139,   139,   140,   140,
   140,    55,   161,   161,   161,    34,    34,   182,   131,   192,
   192,    37,   162,   162,   162,   190,   190,   164,   193,   193,
   193,   193,    94,    94,    94,    94,    94,    94,    94,    94,
    94,    94,   194,   194,   195,   196,    54,    54,    54,    54,
    54,    54,    54,    87,    87,    87,    87,    87,    87,   199,
   137,   200,   201,   137,    88,    88,    88,    88,   202,   138,
   203,   204,   138,   197,   160,   160,   160,   205,   189,   206,
   207,   207,    42,    42,    35,    35,    82,    82,   117,   208,
    21,   186,   184,   184,   166,   166,   209,   209,   144,   144,
   144,   143,   143,   143,   143,   141,   141,   142,   210,   210,
   210,   168,   118,   118,    38,   128,   128,   128,   172,   172,
   172,   172,   213,   213,   213,   214,   214,   214,   214,   214,
   214,   214,   125,   125,   125,   125,   125,   125,   125,   125,
   215,   215,   215,   215,   215,   215,   216,   147,   147,   147,
   147,   145,   145,   145,   145,   146,   146,   146,   217,   217,
   217,   217,    96,    96,   133,   133,   133,   133,   133,   133,
    26,    24,   198,   174,   174,   174,   174,   174,   178,    22,
    17,    17,    17,    17,   218,   218,   218,   219,   219,   219,
   220,   222,   222,   222,   224,   224,   223,   223,    44,    68,
    68,    68,     5,   211,   211,    14,    14,     1,   188,   169,
   169,   169,   169,   169,   169,   225,   225,   225,   225,   170,
   170,   170,   170,   170,   170,    62,    62,   176,   176,   176,
   176,   176,   226,    12,    12,    12,    12,    12,    12,    12,
    12,    12,    12,    12,    12,    12,    12,    12,    12,    12,
    12,    12,    12,    12,    12,    12,    12,    12,    12,    12,
    12,    12,    29,    29,   212,   212,   212,   108,   108,   108,
   108,   109,   109,   109,   109,    52,   230,   230,   231,   227,
   227,   227,   227,   227,   227,   227,   227,   227,   227,   227,
   227,   227,   227,   234,   234,   234,   234,   234,   234,   234,
   191,   229,    25,    63,    63,   232,   232,    61,    61,    61,
    61,   233,   235,   235,    75,   221,   221,   238,   238,   238,
   187,   237,   237,   237,   237,   237,   237,   237,   236,    51,
    51,    51,    51,    51,    10,    10,    10,    95,    95,    95,
   228 };
static const yytabelem yyr2[]={

     0,     4,     4,     2,     2,     2,     2,     2,     8,     0,
     2,     2,     2,     2,     2,     2,     2,     4,     4,     4,
     4,     4,     4,     4,     0,     6,     4,     6,     8,     6,
     8,    12,    12,    12,     0,     6,     6,     6,     2,     2,
     0,    20,    24,     6,     0,     8,    10,     2,     2,     0,
     6,    10,    14,     2,     4,     6,    10,     2,     2,    10,
     2,     2,     2,     2,    10,     4,     8,     2,     2,     4,
     4,     1,     5,     9,    12,     0,     5,     9,    12,    16,
     4,     8,     0,     2,     2,    10,     2,     3,     2,     3,
     0,     2,     2,     2,     4,     4,     4,     0,     6,     1,
     3,     7,    10,     0,     5,     7,    10,    14,     1,    14,
     1,     1,    20,    10,    10,    10,     1,    16,     2,     4,
     0,    12,    14,     2,     4,     1,    12,     1,    10,     3,
     1,    18,     1,    22,     3,     6,     0,    10,    10,    10,
    10,    10,    10,     8,    12,     2,     2,     0,     2,     2,
     8,     2,     6,     6,     6,     2,     2,     2,     2,     2,
     2,     0,    16,    20,     2,     2,     4,     8,     6,     2,
     2,     4,     4,     6,     6,     8,     8,     6,     0,     2,
     4,     2,     6,     8,     6,    10,    10,    10,    18,    12,
     8,     2,     8,    14,     0,     2,     2,     4,     4,    10,
    10,    10,    10,     8,     6,     8,     8,     8,     8,     4,
     1,     3,     7,     7,     2,     2,     4,     2,     2,     2,
     1,    10,     2,     8,     1,    10,     2,     0,     2,     6,
     3,     2,     6,     6,     2,     0,     4,     4,     4,     4,
     2,     0,     6,     0,     2,     2,     2,     6,     2,     6,
     3,     7,     2,     6,     2,     6,    10,    22,    46,     2,
     2,     0,     6,     3,     7,     2,     2,     2,     0,     4,
    10,    10,    18,     2,    10,    12,     0,     8,    12,     8,
     0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     4,     4,     4,     4,     4,     4,     4,     4,     4,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     3,     2,     2,     2,     2,     2,     0,    16,
    20,    12,     0,     8,    12,     0,     5,     6,     4,     0,
     4,     2,     0,     6,    10,     0,    12,     6,     2,     8,
    12,     2,     3,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     8,     2,     2,     2,     2,     2,
     2,     2,     2,     3,     3,     3,     3,     3,     3,     1,
    14,     1,     1,    20,     0,     3,     3,     3,     1,    14,
     1,     1,    20,     4,     0,     6,     2,     1,    10,     2,
     0,     2,     2,     2,     3,     9,     2,     6,    18,    12,
     6,     6,     0,     8,     6,    10,     6,    12,     0,    16,
    20,     2,     2,     2,     2,     2,     2,    12,     4,     4,
     4,     2,     2,     6,     2,     0,     2,     2,     2,     8,
     6,    12,     0,     2,     6,     0,     2,     8,    12,     6,
    12,    16,     2,     2,     8,    12,     2,     2,     2,     6,
     6,     6,     6,     6,     6,     6,     4,     0,    10,    10,
     6,     0,    10,    10,     6,     0,     8,    12,    14,    18,
    18,    22,     0,    10,     0,     2,     2,     2,     2,     2,
     6,     6,     4,     0,     2,    12,     6,    16,     6,     8,
     2,     8,    12,     2,     2,     2,     2,     2,     4,     6,
     8,     0,    12,    14,    12,     6,     2,     2,     0,     0,
     2,     2,     2,     6,     6,     0,     2,     2,     6,     2,
     8,    12,     6,    12,    16,     0,     2,     2,     2,     2,
     8,    12,     6,    12,    16,     2,     2,     0,     6,     2,
    10,     6,     6,     0,     4,     4,     4,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     6,     6,
     6,     4,     4,     4,     4,     4,     4,     4,     4,     4,
     4,     4,     2,     2,    10,    10,     4,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     4,    10,     4,    20,
    24,    20,    24,    16,    20,    20,    24,    20,    24,    20,
    24,    24,    28,     0,     2,     2,     2,     4,     4,     4,
    12,    10,     6,     2,     6,     4,     8,     0,     2,     2,
     2,     2,     2,     2,    18,     0,    10,     0,    12,    16,
    10,     0,     2,     2,     2,     4,     4,     4,     6,     2,
     2,     2,     2,     2,     2,     2,     2,     0,     2,     2,
    10 };
static const yytabelem yychk[]={

-10000000,    -1,   -73,   -74,   -75,   -76,  -179,   371,   411,   355,
   353,   -74,   -75,   -76,    -2,    -3,    -5,    -4,   304,   303,
    -2,   -90,   290,  -171,   274,   290,   274,    -2,    -3,   285,
  -172,  -213,    -2,  -214,   276,    -2,  -236,    -2,   -91,   274,
  -180,  -185,  -186,   -56,  -136,  -187,  -183,  -188,  -149,   -11,
   -21,  -135,  -189,  -151,  -190,   -22,   -23,   -24,   -25,   -26,
   -27,  -191,  -132,   320,   308,   -87,   -88,   -89,  -120,  -139,
  -141,  -143,   -32,   375,   374,    -2,   393,   346,   306,   366,
   348,   365,   347,   -94,   380,   349,   376,   401,   377,   334,
   400,   339,   307,   356,   363,   359,   422,   421,   311,   360,
   350,   321,   312,   313,   361,   362,   358,   369,   383,   384,
   402,   385,   403,   404,   387,   386,   317,   378,   419,   405,
   407,   397,   414,   408,   406,   398,   420,   409,   275,   279,
   274,   280,   279,  -214,    -2,   275,   279,   -92,   -94,   -98,
   -99,   345,   364,   328,  -185,  -186,   -56,  -136,  -187,  -183,
  -188,  -149,   -11,  -165,  -166,    -2,   -57,   274,   -57,   -57,
   -57,   -57,   -58,   282,  -142,   -34,    -2,   -58,   -58,  -145,
   274,  -147,   274,  -184,   -57,   282,  -225,  -226,  -210,  -227,
   394,  -211,  -116,  -212,   298,  -208,  -129,  -117,  -119,   343,
   344,   274,   -12,   -16,  -195,  -215,  -216,   -48,   -30,  -177,
  -228,  -107,  -124,  -224,  -209,  -229,  -230,   -17,   308,   318,
   336,   381,   -18,   343,   314,   316,   315,   337,   382,   417,
   335,   413,   322,   295,   309,   338,    -2,  -231,   -47,   -70,
   -72,   298,   276,   282,   283,   -12,  -165,  -154,  -205,  -152,
   -95,   412,   388,   -96,   280,  -157,  -174,    -2,  -173,    -2,
  -157,  -173,    -2,    -2,  -133,   -96,   349,   376,   377,   401,
  -213,    -2,  -213,   -49,   -50,   -51,   -52,   -54,    -2,   -47,
   -55,   287,   288,   267,   289,   266,   305,   -67,  -197,   -13,
  -148,  -198,   -10,   260,   276,   -68,   -14,   259,   258,    -2,
   277,   285,    -2,   310,   -94,   -95,   -99,   275,   419,   419,
   279,   285,   279,   273,   -58,  -108,  -109,   341,   340,   397,
   395,   372,   415,   398,   396,   373,   416,   -69,   282,   -69,
   -69,   -58,  -140,   -34,    -7,   274,   -10,   260,   285,   274,
   -96,  -144,   -34,   -33,   -34,  -146,   -34,  -108,  -109,  -146,
  -108,  -109,  -181,  -182,   -69,   274,   330,  -175,  -176,    -2,
  -217,   367,   285,   285,   285,   389,   342,   368,   418,   391,
   379,   390,   273,   273,   273,   273,   274,  -211,   274,  -112,
  -126,  -169,   370,   357,  -155,    -2,   -16,  -195,  -215,  -216,
   -48,   -30,  -177,  -228,  -107,  -124,  -224,  -209,  -229,  -230,
   285,   285,   285,   273,   292,  -178,   -17,    -2,   -17,  -178,
  -162,  -193,    -2,   -47,   -17,  -193,   -29,   -12,   285,   274,
   274,   274,   274,   -12,   274,   274,   274,   274,    -2,    -2,
   284,   -12,   -12,   284,   280,   274,   285,   274,    -2,   -19,
  -125,   -51,   -52,   -54,    -2,   -47,   -55,  -130,   274,  -131,
   298,    -6,   274,   -10,    -2,   274,   285,   -96,   -96,   -96,
   -96,  -157,   -49,   285,   279,   280,   285,   285,   285,   285,
   285,    -2,   274,   275,   -15,   286,   281,   284,   287,   288,
   267,   294,   265,   -50,   287,   288,   -19,   258,   264,   261,
   257,   263,   262,   280,  -237,  -189,  -135,   -22,   -93,   -86,
   -87,   -88,   -89,   -95,   -96,  -100,  -102,  -166,    -2,   -49,
   -59,  -162,    -2,   -47,   279,   279,   279,   279,  -137,   -34,
    -7,   274,  -138,   -34,  -103,   -34,  -121,   -34,   285,   279,
   274,    -7,  -153,    -2,   285,   279,   274,   279,   285,   274,
   285,   279,   274,   279,   279,   275,   285,   279,   275,   279,
   279,   285,    -2,   274,  -238,  -192,    -2,   -19,   285,   279,
   273,   298,   274,   274,   274,   274,   274,   274,   274,  -118,
  -167,   274,  -168,   -53,   -49,  -118,  -118,  -118,   -19,  -126,
  -169,  -128,   287,   288,  -128,   279,   280,   285,   285,   285,
   -18,   382,   -18,   285,   273,   285,   285,   279,   285,   273,
   280,   285,   285,   -19,   -19,   -19,   -19,   -19,   -19,  -178,
   -19,   285,   285,    -2,   325,   351,    -2,   -19,   -49,   -51,
   -52,   -54,    -2,   -47,   -55,   -19,   -19,   277,   -15,   286,
  -125,   274,   280,   -71,   -19,   274,    -2,   -71,  -123,   -19,
    -2,   370,   357,  -101,    -2,  -101,  -101,   -58,   285,   284,
    -2,   -49,  -234,   -20,  -189,  -151,   -21,   -22,   -23,   -24,
   -25,   -26,   -27,   285,  -213,   -49,   -49,   -49,   276,   -49,
  -235,  -189,  -135,   -22,   -39,  -220,   399,  -221,   346,   333,
   -86,   -78,    -7,   274,   -78,   -78,   -96,   -78,  -101,  -101,
   273,   285,   279,   280,  -109,   341,  -108,   340,  -108,  -109,
   285,  -200,   274,    -7,   285,  -203,   274,   279,   285,   274,
   279,   285,   274,   -34,   -35,    -3,   275,   279,   279,   280,
   -34,  -153,   -34,   -35,   -34,   -35,  -109,  -108,  -109,  -108,
  -182,  -181,   -96,  -159,  -160,  -161,   -19,    -2,   279,   285,
   274,   -96,   275,    -2,  -217,   -49,   273,  -169,  -232,   -61,
   370,   357,  -110,   323,  -232,   -60,   -61,   -60,  -232,   -60,
  -232,  -167,   279,   284,   275,   296,   293,   296,   293,  -155,
   -49,   -19,   274,   -19,   -19,  -193,   -19,   -19,   -49,   275,
   275,   275,   275,   275,   275,   285,   275,   -20,   -20,   280,
   284,   275,   275,  -125,   -51,   -52,   -19,   -19,   -19,   -49,
   275,   284,   -19,   275,   275,   363,   -19,   -19,   285,   279,
   285,   285,   -97,    -2,   -49,   280,   284,   -20,  -189,  -151,
   -29,   -21,   -22,   -23,   -24,   -25,   -26,   -27,  -134,   -20,
  -135,   275,   284,   281,   -19,   281,   284,   329,   -40,   -41,
   -65,   399,    -2,   284,    -7,   284,   284,   -78,   -97,   -77,
   299,   285,   -49,  -162,   -19,   -49,   275,   275,   275,   275,
   275,   275,   279,  -199,   275,   279,   279,  -202,   -34,  -104,
   -34,   -35,   274,   279,   280,    -9,    -8,   -10,  -153,   -49,
   274,   279,   274,   279,   274,   275,   275,   275,   275,   275,
   274,   275,   279,   279,   274,  -192,  -207,   -19,   273,   274,
   298,   279,   -62,  -169,  -170,  -206,    -2,   280,   279,   279,
   -62,   279,   279,   279,   279,   275,  -168,   -49,  -211,  -116,
  -127,  -170,    -2,  -170,  -127,  -170,   280,   281,   284,   -19,
   273,   281,   284,   -29,   -28,   -19,   319,   -28,   -28,   -72,
   -12,   -12,   -19,   -29,   -12,   -12,   -49,   285,   285,  -125,
   284,   275,   281,   284,   -19,   275,   -19,    -2,   370,   357,
    -2,   279,   285,   281,   -49,   -49,   332,   -12,   -20,  -135,
   -49,   277,   -49,   331,   -41,   284,   260,   270,   286,   271,
  -222,  -223,   -41,  -115,   -65,   273,   -80,   -34,   275,   279,
   -80,   -80,   -97,   285,   285,   291,   284,   -34,   -35,    -9,
   -10,   -34,   -35,   274,   -36,    -3,   274,   279,   -35,   -36,
   -49,   275,   279,   275,   281,  -153,  -153,   -35,   -36,   -35,
  -159,  -160,    -2,   -19,   274,   279,   -49,  -158,   -53,  -170,
  -232,   297,   279,   280,  -111,   259,   268,  -232,  -233,   -19,
   297,  -233,  -232,  -232,  -232,   279,   284,  -128,  -128,   275,
   275,   -49,   -49,   275,   -19,   -49,   324,   -19,   319,   326,
   284,   -29,   284,   326,   326,   285,   325,   351,   281,   -19,
   -49,   284,   -19,   -19,    -2,   284,   281,   327,   277,   281,
   284,   -42,   260,   270,   331,  -223,   284,  -113,   274,  -114,
   269,   272,  -150,   260,   301,   302,   -84,   285,   274,    -9,
   285,   285,   285,   260,   -49,   274,   279,   275,   274,   279,
  -106,   279,   -35,   -36,   279,   279,   281,    -9,   279,   279,
   279,   279,   275,   275,   274,   275,  -207,  -156,   -19,   275,
   279,   273,   279,   -63,  -219,   274,   -19,   289,  -206,   -49,
   281,   279,   279,   275,   279,   -63,   279,   279,   279,   279,
  -168,   -49,   284,   284,   281,   284,   281,   -72,   281,   -29,
   284,   -29,   284,   -29,   -29,  -178,   281,   -19,   -49,   -42,
   285,   284,   -64,   -65,   -65,   -65,   285,   279,   -81,   275,
   281,  -201,   -83,   -36,  -204,   -36,   -36,   -35,   279,   279,
   -36,  -122,   -19,   275,  -153,  -122,   -36,   -37,   -19,   -19,
   279,   279,   275,   285,  -158,  -158,  -233,  -219,   -19,   294,
   -19,   280,   281,   284,  -111,  -233,   285,  -196,    -2,   -49,
  -233,  -233,  -233,   279,   -66,   -19,   -66,   -49,   -29,   -29,
   275,   281,   285,   -64,   284,   -65,   -34,   -82,   -35,   -35,
   279,   275,   -35,   275,   279,   279,   -36,  -122,   279,   275,
   279,   275,   279,   279,   275,  -156,   -19,   275,   275,   279,
   275,   279,   275,  -218,   260,   301,   300,   -49,   -49,   281,
   275,   279,   275,   275,   279,   275,   279,   275,   279,   279,
  -168,   275,   275,   281,   -12,   284,  -194,   -42,   288,   275,
   274,   285,   279,   279,   -36,   279,   -35,  -105,    -3,   279,
   275,  -122,  -122,   -37,   -38,   -19,   275,   285,   285,  -158,
   285,  -196,   281,   284,   281,   285,  -196,   285,   285,  -196,
   285,  -196,   285,  -196,  -233,   279,  -194,   285,   -85,   -83,
   -35,   -83,   -36,   279,   275,  -122,   275,   275,   279,   275,
   275,   275,   -49,   275,   275,   275,   275,   275,   279,  -168,
   285,   -82,   275,   275,   275,  -105,   275,   -38,   285,   285,
   281,   285,   285,   285,   285,   285,  -196,   279,   285,   275,
   275,   275,  -168,   -83,   285,   279,   275,  -168,   279,  -168,
   279,  -168,   279,  -168,   279,  -168,   279,  -168 };
static const yytabelem yydef[]={

    90,    -2,   517,    91,    92,    93,   210,   210,   116,   312,
   313,    94,    95,    96,   261,   211,   214,   215,   512,   165,
     0,   210,     0,     0,   210,   210,   210,   241,   212,    -2,
     0,   428,   436,   433,   210,   213,     0,     0,   120,     0,
   210,   281,   282,   283,   284,   285,   286,   287,   288,   289,
   299,   300,   301,   302,   303,   304,   305,   306,   307,   308,
   309,   310,   311,   210,   136,   136,   136,   136,   136,    75,
   210,    75,    75,   461,   457,   136,   525,    82,    82,   210,
   224,   387,   220,   647,   472,   210,   210,   210,   210,   210,
   210,   472,   363,   364,   365,   366,   367,   368,   375,   376,
   377,   129,   157,   158,   159,   160,   314,   315,   316,   317,
   415,   416,   411,   412,   413,   414,    38,    39,   342,   343,
   344,   345,   346,   347,   348,   349,   350,   351,   262,   210,
   210,    -2,   210,     0,   436,     0,   210,     0,   647,     0,
   123,     0,     0,   275,   290,   291,   292,   293,   294,   295,
   296,   297,   298,     0,   252,     0,    75,     0,    71,    71,
    71,    75,    -2,     0,     0,     0,   472,    -2,    -2,    -2,
     0,    -2,     0,   276,    71,     0,     0,   526,   527,   528,
    -2,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,    -2,    82,     0,     0,     0,   547,   548,   549,   550,
   551,   552,   553,   554,   555,   556,   557,     0,   210,   210,
    -2,   210,    82,     0,     0,     0,     0,    82,     0,     0,
     0,     0,   210,   210,    82,    82,   490,     0,   493,    83,
    84,   210,    -2,     0,   210,    -2,     0,   472,   472,   472,
   472,   648,   649,   210,    -2,     0,   266,   484,     0,   265,
     0,     0,     0,     0,   210,   475,   476,   477,   478,   479,
   430,   436,     0,     0,    53,    -2,    57,    60,    61,    62,
    63,    -2,    -2,   641,   642,   643,   585,   356,   357,   358,
   359,   360,    -2,    -2,    -2,     0,     0,   644,   646,   439,
   434,   631,   638,   374,   647,   472,   124,   242,   125,   127,
   210,   401,   210,    -2,    -2,     0,     0,     0,     0,   577,
   578,   579,   580,   581,   582,   583,   584,   210,     0,   210,
   210,    -2,     0,     0,    76,     0,    87,   645,   204,   210,
   326,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,   210,     0,    -2,    -2,   518,     0,   267,     0,
   539,     0,   418,   419,   420,     0,     0,     0,     0,     0,
     0,     0,    -2,    -2,    -2,    -2,    -2,   576,   210,   210,
   425,    -2,   148,   149,   519,   226,     0,     0,     0,   561,
   562,   563,   564,   565,   566,   567,   568,   569,   570,   571,
   544,   545,   546,    82,    82,     0,     0,   490,     0,     0,
     0,     0,   338,   341,     0,     0,   456,    82,   573,    -2,
    -2,    -2,    -2,    82,    -2,    -2,   210,    -2,     0,     0,
   210,    82,    82,   210,    -2,    -2,   586,    -2,   588,     0,
   179,    -2,   181,   442,   443,   446,   447,   448,    -2,   191,
   210,    80,    -2,    86,   166,    -2,   400,   210,   210,   210,
    75,     0,     0,   233,   210,    -2,   481,   612,   480,   168,
     9,     0,   210,   429,    -2,    -2,   437,    -2,     3,     4,
     5,     6,     7,    54,   510,   511,     0,    69,   482,     2,
    70,   209,   383,    -2,     0,   632,   633,   634,   374,   118,
    99,    99,    99,   472,    99,   210,   210,   253,     0,   404,
     0,   246,   338,   341,     0,     0,     0,     0,   371,     0,
    72,     0,   380,     0,     0,     0,     0,     0,   203,   210,
     0,     0,     0,   222,   205,   210,   210,   210,   206,     0,
   207,   210,     0,     0,     0,   464,   208,     0,   460,     0,
   276,   279,   472,    -2,     0,     0,   472,     0,   542,   210,
    -2,   210,   617,   617,   617,   617,   617,   617,   617,   513,
   422,    -2,   254,   421,    58,   514,   153,   154,     0,     0,
   259,     0,   426,   427,     0,   210,    -2,   558,   559,   560,
    -2,     0,    -2,   450,    -2,   451,   452,   210,   453,    -2,
    -2,   454,   455,     0,     0,     0,     0,     0,     0,     0,
     0,   135,   177,     9,   505,   406,     9,     0,     0,    -2,
    -2,    -2,    -2,    -2,    -2,     0,     0,    50,    -2,    -2,
   180,    -2,    -2,     0,   273,    -2,   328,     0,     0,   169,
    -2,    -2,    -2,     0,   263,     0,     0,   210,   489,    -2,
   486,     0,     9,   604,   605,   606,    10,    11,    12,    13,
    14,    15,    16,     9,     0,    55,     0,     0,    -2,     0,
     0,   635,   636,   637,   622,   623,    44,     0,   210,   117,
   119,     0,   100,     0,     0,     0,    99,   210,    97,     0,
    -2,    64,    -2,    -2,     0,     0,     0,     0,     0,     0,
   199,     0,   369,     0,   200,     0,   378,   210,   201,   130,
   210,   202,     0,     0,     0,   394,    77,     0,   210,    -2,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,   210,   327,     0,   244,   245,   386,   443,   210,   630,
    -2,   330,   403,     0,   541,   538,     0,     0,     0,   210,
   618,   619,   620,     0,     0,     0,   210,     0,     0,     0,
     0,     0,    -2,    -2,     0,   210,   210,   210,   210,   522,
     0,     8,    -2,   354,   488,     0,   333,     0,     0,    82,
    24,    24,    24,    82,    82,    -2,    82,    82,    82,   491,
    -2,     0,     0,   182,    -2,   184,     0,     0,     0,     0,
   449,    -2,     0,    81,   167,    -2,   171,   172,   225,   210,
   388,   221,     0,   250,     0,    -2,    -2,   607,   608,   609,
     0,    17,    18,    19,    20,    21,    22,    23,     9,   195,
   196,   431,    -2,   438,     0,   440,    -2,   624,   235,     0,
   234,    -2,     0,   210,     0,   210,   210,   210,     0,     0,
     0,   128,   405,   247,     0,     0,   137,   139,   138,   140,
   141,   142,   210,     0,    73,     0,   210,     0,     0,     0,
     0,     0,     0,     0,    -2,     0,     0,    -2,     0,     0,
   210,   210,     0,     0,     0,   466,   462,   463,   458,   459,
    -2,   277,    -2,   210,    -2,     0,     0,   391,    -2,    -2,
   210,   617,   615,   535,   536,   529,   226,     0,   617,    -2,
    65,    -2,   617,   617,   617,   423,   255,     0,   574,   575,
   425,   260,   389,   425,     0,     0,    -2,   520,    -2,     0,
    -2,   339,    -2,    51,    -2,     0,    82,    -2,    -2,    84,
    82,    82,     0,   650,    82,    82,     0,   611,   587,   183,
    -2,   190,   444,    -2,     0,   192,   173,    -2,    -2,    -2,
   264,   210,   336,   473,     0,     0,   610,    82,   197,   198,
    56,     0,     0,    43,     0,     0,   236,   237,   238,   239,
   235,     0,   506,   507,   234,     0,   110,     0,   101,     0,
   110,   110,     0,   121,   126,     0,    -2,     0,     0,     0,
    89,     0,     0,   132,     0,   230,     0,     0,     0,     0,
     0,    78,     0,   417,   223,     0,     0,     0,     0,     0,
     0,   385,     0,     0,    -2,    -2,   540,     0,   240,     0,
     0,    -2,   210,    -2,     0,   145,   146,     0,     0,   621,
    -2,     0,     0,     0,     0,    -2,    -2,     0,     0,   189,
   399,     0,     0,     0,   334,     0,    82,     0,    82,    31,
    82,    26,    82,    32,    33,   210,   504,   407,   492,   185,
     0,    -2,   175,   176,   251,    -2,   485,   193,   321,   441,
     0,     0,   392,   393,   500,     0,   235,   235,   235,   151,
   155,   156,     0,   217,   218,   219,     0,   113,   108,     0,
   114,   115,   122,    98,     0,   372,     0,    74,   381,     0,
     0,     0,     0,     0,     0,    -2,   395,     0,   210,    -2,
     0,    -2,   467,    -2,    -2,   190,     0,     0,   228,     0,
    -2,    -2,    -2,   616,   613,    -2,   497,    -2,   532,     0,
   143,     0,    -2,     0,   210,    66,    -2,    -2,    -2,    -2,
   256,    59,    -2,    -2,   523,    -2,   521,    85,   340,    52,
    82,    29,    82,    25,    27,     0,   445,   274,     0,     0,
    45,   235,     0,    67,   152,   235,   626,   210,     0,   102,
   340,     0,     0,   231,     0,     0,     0,     0,     0,    -2,
     0,     0,   164,    79,     0,     0,     0,     0,   331,     0,
    -2,    -2,   628,   468,     0,     0,     0,     0,   273,     6,
   498,    -2,   530,    -2,     0,     0,   593,     0,   355,     0,
     0,     0,     0,    -2,     0,    68,     0,     0,    28,    30,
    82,   487,    46,     0,     0,     0,     0,     0,   396,     0,
     0,   370,     0,   379,     0,     0,     0,     0,    -2,   319,
    -2,   409,    -2,    -2,   324,     0,   229,     0,     0,    -2,
     0,   210,   614,   499,   494,   495,   496,     0,     0,   144,
     0,   210,     0,     0,   210,     0,   210,     0,   210,    -2,
     0,   188,   398,   524,    82,     0,     0,   352,   353,   150,
   111,     0,     0,     0,   232,     0,     0,     0,   134,    -2,
   162,     0,     0,     0,     0,   424,   629,   469,   470,     0,
   589,     0,   533,    -2,   531,   591,     0,   594,   595,     0,
   597,     0,   599,     0,     0,    -2,     0,   502,     0,     0,
   397,     0,     0,     0,   131,     0,   320,   410,    -2,    41,
     0,     0,     0,     0,     0,     0,     0,     0,   210,     0,
   503,     0,   109,   373,   382,     0,   163,     0,   471,   590,
   534,   592,   596,   598,   600,   601,     0,    -2,     0,   133,
    42,     0,   257,     0,   602,    -2,   112,     0,    -2,     0,
    -2,     0,    -2,     0,    -2,     0,    -2,   258 };
typedef struct
#ifdef __cplusplus
	yytoktype
#endif
{ char *t_name; int t_val; } yytoktype;
#ifndef YYDEBUG
#	define YYDEBUG	1	/* allow debugging */
#endif

#if YYDEBUG

yytoktype yytoks[] =
{
	"DECIMAL_NUMBER",	257,
	"UNSIGNED_NUMBER",	258,
	"EDGE_OR_UNSIGNED",	259,
	"ZERO_OR_ONE",	260,
	"BINARY_NUMBER",	261,
	"OCTAL_NUMBER",	262,
	"HEX_NUMBER",	263,
	"REAL_NUMBER",	264,
	"BINARY_OPERATOR",	265,
	"UNARY_OPERATOR",	266,
	"OPERATOR",	267,
	"EDGE_DESCRIPTOR",	268,
	"EDGE_OR_BINARY_OPERATOR",	269,
	"EX",	270,
	"LEVEL_SYMBOL",	271,
	"EDGE_SYMBOL",	272,
	"EQUAL",	273,
	"OPENPAREN",	274,
	"CLOSEPAREN",	275,
	"OPENCURLYBRAC",	276,
	"CLOSECURLYBRAC",	277,
	"BACKSLASH",	278,
	"COMMA",	279,
	"OPENSQBRAC",	280,
	"CLOSESQBRAC",	281,
	"POUND",	282,
	"AT",	283,
	"COLON",	284,
	"SEMICOLON",	285,
	"QUESTIONMARK",	286,
	"PLUS",	287,
	"MINUS",	288,
	"TILDA",	289,
	"DOT",	290,
	"SINGLE_QUOTE",	291,
	"LESSOREQUAL",	292,
	"DOUBLERIGHTARROW",	293,
	"EQUIV_EXPR",	294,
	"RIGHTARROW",	295,
	"STARARROWRIGHT",	296,
	"TRIAMPERSAND",	297,
	"DOLLAR",	298,
	"DES_ASSIGNMENT",	299,
	"KNOWN_BIT",	300,
	"ONE_KNOWN_BIT",	301,
	"UNKNOWN_BIT",	302,
	"ESCAPED_IDENTIFIER",	303,
	"SIMPLE_IDENTIFIER",	304,
	"STRING",	305,
	"ALWAYS",	306,
	"AND",	307,
	"ASSIGN",	308,
	"BEGN",	309,
	"BODY",	310,
	"BUF",	311,
	"BUFIF0",	312,
	"BUFIF1",	313,
	"CASE",	314,
	"CASEX",	315,
	"CASEZ",	316,
	"CMOS",	317,
	"DEASSIGN",	318,
	"DEFAULT",	319,
	"DEFPARAM",	320,
	"DFF",	321,
	"DISABLE",	322,
	"EDGE",	323,
	"ELSE",	324,
	"END",	325,
	"ENDCASE",	326,
	"ENDFUNCTION",	327,
	"ENDMODULE",	328,
	"ENDPRIMITIVE",	329,
	"ENDSPECIFY",	330,
	"ENDTABLE",	331,
	"ENDTASK",	332,
	"ENDUNIT",	333,
	"EVENT",	334,
	"FOR",	335,
	"FORCE",	336,
	"FOREVER",	337,
	"FORK",	338,
	"FUNCTION",	339,
	"HIGHZ0",	340,
	"HIGHZ1",	341,
	"HOLD",	342,
	"IF",	343,
	"IFNONE",	344,
	"IN",	345,
	"INITL",	346,
	"INOUT",	347,
	"INPUT",	348,
	"INTEGER",	349,
	"INV",	350,
	"JOIN",	351,
	"LARGE",	352,
	"MACROMODULE",	353,
	"MEDIUM",	354,
	"MODULE",	355,
	"NAND",	356,
	"NEGEDGE",	357,
	"NMOS",	358,
	"NOR",	359,
	"NOT",	360,
	"NOTIF0",	361,
	"NOTIF1",	362,
	"OR",	363,
	"OUT",	364,
	"OUTPUT",	365,
	"PARAMETER",	366,
	"PATHPULSE",	367,
	"PERIOD",	368,
	"PMOS",	369,
	"POSEDGE",	370,
	"PRIMITIVE",	371,
	"PULL0",	372,
	"PULL1",	373,
	"PULLDOWN",	374,
	"PULLUP",	375,
	"REAL",	376,
	"REALTIME",	377,
	"RCMOS",	378,
	"RECOVERY",	379,
	"REG",	380,
	"RELEASE",	381,
	"REPEAT",	382,
	"RNMOS",	383,
	"RPMOS",	384,
	"RTRAN",	385,
	"RTRANIF0",	386,
	"RTRANIF1",	387,
	"SCALARED",	388,
	"SETUP",	389,
	"SETUPHOLD",	390,
	"SKEW",	391,
	"SMALL",	392,
	"SPECIFY",	393,
	"SPECPARAM",	394,
	"STRONG0",	395,
	"STRONG1",	396,
	"SUPPLY0",	397,
	"SUPPLY1",	398,
	"TABLE",	399,
	"TASK",	400,
	"TIME",	401,
	"TRAN",	402,
	"TRANIF0",	403,
	"TRANIF1",	404,
	"TRI",	405,
	"TRI0",	406,
	"TRI1",	407,
	"TRIAND",	408,
	"TRIOR",	409,
	"TRIREG",	410,
	"UNIT",	411,
	"VECTORED",	412,
	"WAIT",	413,
	"WAND",	414,
	"WEAK0",	415,
	"WEAK1",	416,
	"WHILE",	417,
	"WIDTH",	418,
	"WIRE",	419,
	"WOR",	420,
	"XNOR",	421,
	"XOR",	422,
	"-unknown-",	-1	/* ends search */
};

char * yyreds[] =
{
	"-no such reduction-",
	"always_construct : ALWAYS statement",
	"binary_number : size BINARY_NUMBER",
	"binary_operator : PLUS",
	"binary_operator : MINUS",
	"binary_operator : OPERATOR",
	"binary_operator : EQUIV_EXPR",
	"binary_operator : BINARY_OPERATOR",
	"blocking_assignment : reg_lvalue EQUAL delay_or_event_control expression",
	"block_item_declaration : /* empty */",
	"block_item_declaration : parameter_declaration",
	"block_item_declaration : reg_declaration",
	"block_item_declaration : integer_declaration",
	"block_item_declaration : real_declaration",
	"block_item_declaration : time_declaration",
	"block_item_declaration : realtime_declaration",
	"block_item_declaration : event_declaration",
	"block_item_declaration : block_item_declaration parameter_declaration",
	"block_item_declaration : block_item_declaration reg_declaration",
	"block_item_declaration : block_item_declaration integer_declaration",
	"block_item_declaration : block_item_declaration real_declaration",
	"block_item_declaration : block_item_declaration time_declaration",
	"block_item_declaration : block_item_declaration realtime_declaration",
	"block_item_declaration : block_item_declaration event_declaration",
	"case_item : /* empty */",
	"case_item : expression COLON statement_or_null",
	"case_item : DEFAULT statement_or_null",
	"case_item : DEFAULT COLON statement_or_null",
	"case_item : case_item expression COLON statement_or_null",
	"case_item : case_item DEFAULT statement_or_null",
	"case_item : case_item DEFAULT COLON statement_or_null",
	"case_statement : CASE OPENPAREN expression CLOSEPAREN case_item ENDCASE",
	"case_statement : CASEZ OPENPAREN expression CLOSEPAREN case_item ENDCASE",
	"case_statement : CASEX OPENPAREN expression CLOSEPAREN case_item ENDCASE",
	"charge_strength : /* empty */",
	"charge_strength : OPENPAREN SMALL CLOSEPAREN",
	"charge_strength : OPENPAREN MEDIUM CLOSEPAREN",
	"charge_strength : OPENPAREN LARGE CLOSEPAREN",
	"cmos_switchtype : CMOS",
	"cmos_switchtype : RCMOS",
	"cmos_switch_instance : /* empty */",
	"cmos_switch_instance : name_of_gate_instance OPENPAREN output_terminal COMMA input_terminal COMMA ncontrol_terminal COMMA pcontrol_terminal CLOSEPAREN",
	"cmos_switch_instance : cmos_switch_instance COMMA name_of_gate_instance OPENPAREN output_terminal COMMA input_terminal COMMA ncontrol_terminal COMMA pcontrol_terminal CLOSEPAREN",
	"combinational_body : TABLE combinational_entry ENDTABLE",
	"combinational_entry : /* empty */",
	"combinational_entry : level_input_list COLON output_symbol SEMICOLON",
	"combinational_entry : combinational_entry level_input_list COLON output_symbol SEMICOLON",
	"comment : short_comment",
	"comment : long_comment",
	"comment_text : /* empty */",
	"concatenation : OPENCURLYBRAC expression CLOSECURLYBRAC",
	"conditional_statement : IF OPENPAREN expression CLOSEPAREN statement_or_null",
	"conditional_statement : IF OPENPAREN expression CLOSEPAREN statement_or_null ELSE statement_or_null",
	"constant_expression : constant_primary",
	"constant_expression : unary_operator constant_primary",
	"constant_expression : constant_expression binary_operator constant_expression",
	"constant_expression : constant_expression QUESTIONMARK constant_expression COLON constant_expression",
	"constant_expression : string",
	"constant_mintypmax_expression : constant_expression",
	"constant_mintypmax_expression : constant_expression COLON constant_expression COLON constant_expression",
	"constant_primary : number",
	"constant_primary : identifier",
	"constant_primary : concatenation",
	"constant_primary : multiple_concatenation",
	"continuous_assign : ASSIGN drive_strength delay3 list_of_net_assignments SEMICOLON",
	"controlled_timing_check_event : timing_check_event_control specify_terminal_descriptor",
	"controlled_timing_check_event : timing_check_event_control specify_terminal_descriptor TRIAMPERSAND timing_check_condition",
	"current_state : level_symbol",
	"data_source_expression : expression",
	"decimal_number : sign UNSIGNED_NUMBER",
	"decimal_number : size DECIMAL_NUMBER",
	"delay2 : /* empty */",
	"delay2 : POUND delay_value1",
	"delay2 : POUND OPENPAREN delay_value1 CLOSEPAREN",
	"delay2 : POUND OPENPAREN delay_value1 COMMA delay_value3 CLOSEPAREN",
	"delay3 : /* empty */",
	"delay3 : POUND delay_value1",
	"delay3 : POUND OPENPAREN delay_value1 CLOSEPAREN",
	"delay3 : POUND OPENPAREN delay_value1 COMMA delay_value3 CLOSEPAREN",
	"delay3 : POUND OPENPAREN delay_value1 COMMA delay_value2 COMMA delay_value3 CLOSEPAREN",
	"delay_control : POUND delay_value",
	"delay_control : POUND OPENPAREN mintypmax_expression CLOSEPAREN",
	"delay_or_event_control : /* empty */",
	"delay_or_event_control : delay_control",
	"delay_or_event_control : event_control",
	"delay_or_event_control : REPEAT OPENPAREN expression CLOSEPAREN event_control",
	"delay_value : unsigned_number",
	"delay_value1 : unsigned_number",
	"delay_value2 : unsigned_number",
	"delay_value3 : unsigned_number",
	"description : /* empty */",
	"description : module_declaration",
	"description : udp_declaration",
	"description : des_module_declaration",
	"description : description module_declaration",
	"description : description udp_declaration",
	"description : description des_module_declaration",
	"des_assignment : /* empty */",
	"des_assignment : DES_ASSIGNMENT SINGLE_QUOTE ZERO_OR_ONE",
	"des_delay2 : /* empty */",
	"des_delay2 : delay_value1",
	"des_delay2 : OPENPAREN delay_value1 CLOSEPAREN",
	"des_delay2 : OPENPAREN delay_value1 COMMA delay_value3 CLOSEPAREN",
	"des_delay3 : /* empty */",
	"des_delay3 : POUND delay_value1",
	"des_delay3 : OPENPAREN delay_value1 CLOSEPAREN",
	"des_delay3 : OPENPAREN delay_value1 COMMA delay_value3 CLOSEPAREN",
	"des_delay3 : OPENPAREN delay_value1 COMMA delay_value2 COMMA delay_value3 CLOSEPAREN",
	"des_gate_instance : name_of_gate_instance OPENPAREN",
	"des_gate_instance : name_of_gate_instance OPENPAREN output_terminal_repeat SEMICOLON input_terminal_repeat CLOSEPAREN",
	"des_gate_instance : des_gate_instance",
	"des_gate_instance : des_gate_instance COMMA name_of_gate_instance OPENPAREN",
	"des_gate_instance : des_gate_instance COMMA name_of_gate_instance OPENPAREN output_terminal_repeat SEMICOLON input_terminal_repeat CLOSEPAREN",
	"des_gate_instantiation : n_input_gatetype des_delay2 COLON des_gate_instance SEMICOLON",
	"des_gate_instantiation : n_output_gatetype des_delay2 COLON des_gate_instance SEMICOLON",
	"des_gate_instantiation : dff_gatetype des_delay2 COLON des_gate_instance SEMICOLON",
	"des_module_declaration : UNIT",
	"des_module_declaration : UNIT identifier list_of_des_ports des_net_declaration BODY des_module_item ENDUNIT",
	"des_module_item : des_gate_instantiation",
	"des_module_item : des_module_item des_gate_instantiation",
	"des_net_declaration : /* empty */",
	"des_net_declaration : net_type vectored_or_scalared range des_delay2 list_of_net_identifiers SEMICOLON",
	"des_net_declaration : des_net_declaration net_type vectored_or_scalared range des_delay2 list_of_net_identifiers SEMICOLON",
	"des_port : des_port_expression",
	"des_port : des_port des_port_expression",
	"des_port_expression : IN WIRE",
	"des_port_expression : IN WIRE list_of_port_identifiers des_assignment SEMICOLON",
	"des_port_expression : OUT WIRE",
	"des_port_expression : OUT WIRE list_of_port_identifiers SEMICOLON",
	"dff_gatetype : DFF",
	"dff_gate_instance : name_of_gate_instance OPENPAREN",
	"dff_gate_instance : name_of_gate_instance OPENPAREN input_terminal COMMA output_terminal COMMA dff_input_terminal CLOSEPAREN",
	"dff_gate_instance : dff_gate_instance COMMA name_of_gate_instance OPENPAREN",
	"dff_gate_instance : dff_gate_instance COMMA name_of_gate_instance OPENPAREN input_terminal COMMA output_terminal COMMA dff_input_terminal CLOSEPAREN",
	"dff_input_terminal : IDENTIFIER",
	"disable_statement : DISABLE identifier SEMICOLON",
	"drive_strength : /* empty */",
	"drive_strength : OPENPAREN strength0 COMMA strength1 CLOSEPAREN",
	"drive_strength : OPENPAREN strength1 COMMA strength0 CLOSEPAREN",
	"drive_strength : OPENPAREN strength0 COMMA HIGHZ1 CLOSEPAREN",
	"drive_strength : OPENPAREN strength1 COMMA HIGHZ0 CLOSEPAREN",
	"drive_strength : OPENPAREN HIGHZ1 COMMA strength0 CLOSEPAREN",
	"drive_strength : OPENPAREN HIGHZ0 COMMA strength1 CLOSEPAREN",
	"edge_control_specifier : EDGE OPENSQBRAC edge_descriptor CLOSESQBRAC",
	"edge_control_specifier : EDGE OPENSQBRAC edge_descriptor COMMA edge_descriptor CLOSESQBRAC",
	"edge_descriptor : EDGE_OR_UNSIGNED",
	"edge_descriptor : EDGE_DESCRIPTOR",
	"edge_identifier : /* empty */",
	"edge_identifier : POSEDGE",
	"edge_identifier : NEGEDGE",
	"edge_indicator : OPENPAREN level_symbol level_symbol CLOSEPAREN",
	"edge_indicator : edge_symbol",
	"edge_input_list : level_symbol edge_indicator level_symbol",
	"edge_sensitive_path_declaration : parallel_edge_sensitive_path_description EQUAL path_delay_value",
	"edge_sensitive_path_declaration : full_edge_sensitive_path_description EQUAL path_delay_value",
	"edge_symbol : EDGE_OR_BINARY_OPERATOR",
	"edge_symbol : EDGE_SYMBOL",
	"enable_gatetype : BUFIF0",
	"enable_gatetype : BUFIF1",
	"enable_gatetype : NOTIF0",
	"enable_gatetype : NOTIF1",
	"enable_gate_instance : /* empty */",
	"enable_gate_instance : name_of_gate_instance OPENPAREN output_terminal COMMA input_terminal COMMA enable_terminal CLOSEPAREN",
	"enable_gate_instance : enable_gate_instance COMMA name_of_gate_instance OPENPAREN output_terminal COMMA input_terminal COMMA enable_terminal CLOSEPAREN",
	"enable_terminal : expression",
	"escaped_identifier : ESCAPED_IDENTIFIER",
	"event_control : AT identifier",
	"event_control : AT OPENPAREN event_expression CLOSEPAREN",
	"event_declaration : EVENT identifier SEMICOLON",
	"event_expression : expression",
	"event_expression : identifier",
	"event_expression : POSEDGE expression",
	"event_expression : NEGEDGE expression",
	"event_expression : event_expression OR expression",
	"event_expression : event_expression OR identifier",
	"event_expression : event_expression OR POSEDGE expression",
	"event_expression : event_expression OR NEGEDGE expression",
	"event_trigger : RIGHTARROW identifier SEMICOLON",
	"expression : /* empty */",
	"expression : primary",
	"expression : unary_operator primary",
	"expression : string",
	"expression : expression binary_operator primary",
	"expression : expression binary_operator unary_operator primary",
	"expression : expression binary_operator string",
	"expression : expression QUESTIONMARK expression COLON expression",
	"expression : expression QUESTIONMARK expression COLON expression",
	"expression : expression QUESTIONMARK expression COLON expression",
	"full_edge_sensitive_path_description : OPENPAREN edge_identifier list_of_path_inputs STARARROWRIGHT list_of_path_outputs polarity_operator COLON data_source_expression CLOSEPAREN",
	"full_path_description : OPENPAREN list_of_path_inputs polarity_operator STARARROWRIGHT list_of_path_outputs CLOSEPAREN",
	"function_call : identifier OPENPAREN expression CLOSEPAREN",
	"function_call : name_of_system_function",
	"function_call : name_of_system_function OPENPAREN expression CLOSEPAREN",
	"function_declaration : FUNCTION range_or_type identifier SEMICOLON function_item_declaration statement ENDFUNCTION",
	"function_item_declaration : /* empty */",
	"function_item_declaration : block_item_declaration",
	"function_item_declaration : input_declaration",
	"function_item_declaration : function_item_declaration block_item_declaration",
	"function_item_declaration : function_item_declaration input_declaration",
	"gate_instantiation : n_input_gatetype drive_strength delay2 n_input_gate_instance SEMICOLON",
	"gate_instantiation : n_output_gatetype drive_strength delay2 n_output_gate_instance SEMICOLON",
	"gate_instantiation : dff_gatetype drive_strength delay2 dff_gate_instance SEMICOLON",
	"gate_instantiation : enable_gatetype drive_strength delay3 enable_gate_instance SEMICOLON",
	"gate_instantiation : mos_switchtype delay3 mos_switch_instance SEMICOLON",
	"gate_instantiation : pass_switchtype pass_switch_instance SEMICOLON",
	"gate_instantiation : pass_en_switchtype delay3 pass_en_switch_instance SEMICOLON",
	"gate_instantiation : cmos_switchtype delay3 cmos_switch_instance SEMICOLON",
	"gate_instantiation : PULLUP pullup_strength pull_gate_instance SEMICOLON",
	"gate_instantiation : PULLDOWN pulldown_strength pull_gate_instance SEMICOLON",
	"hex_number : size HEX_NUMBER",
	"identifier : /* empty */",
	"identifier : IDENTIFIER",
	"identifier : identifier DOT IDENTIFIER",
	"identifier : IDENTIFIER DOT identifier",
	"IDENTIFIER : simple_identifier",
	"IDENTIFIER : escaped_identifier",
	"initial_construct : INITL statement",
	"init_val : ZERO_OR_ONE",
	"init_val : ONE_KNOWN_BIT",
	"init_val : UNKNOWN_BIT",
	"inout_declaration : INOUT",
	"inout_declaration : INOUT range list_of_port_identifiers SEMICOLON",
	"inout_terminal : identifier",
	"inout_terminal : identifier OPENSQBRAC constant_expression CLOSESQBRAC",
	"input_declaration : INPUT",
	"input_declaration : INPUT range list_of_port_identifiers SEMICOLON",
	"input_identifier : identifier",
	"input_port_connection : /* empty */",
	"input_port_connection : expression",
	"input_port_connection : input_port_connection COMMA expression",
	"input_terminal : IDENTIFIER",
	"input_terminal_repeat : input_terminal",
	"input_terminal_repeat : input_terminal_repeat COMMA input_terminal",
	"integer_declaration : INTEGER list_of_register_identifiers SEMICOLON",
	"level_input_list : level_symbol",
	"level_symbol : /* empty */",
	"level_symbol : level_symbol ZERO_OR_ONE",
	"level_symbol : level_symbol EX",
	"level_symbol : level_symbol QUESTIONMARK",
	"level_symbol : level_symbol LEVEL_SYMBOL",
	"limit_value : constant_mintypmax_expression",
	"list_of_des_ports : /* empty */",
	"list_of_des_ports : OPENPAREN des_port CLOSEPAREN",
	"list_of_module_connections : /* empty */",
	"list_of_module_connections : ordered_port_connection",
	"list_of_module_connections : named_port_connection",
	"list_of_net_assignments : net_assignment",
	"list_of_net_assignments : list_of_net_assignments COMMA net_assignment",
	"list_of_net_decl_assignments : net_decl_assignment",
	"list_of_net_decl_assignments : list_of_net_decl_assignments COMMA net_decl_assignment",
	"list_of_net_identifiers : identifier",
	"list_of_net_identifiers : list_of_net_identifiers COMMA identifier",
	"list_of_param_assignments : param_assignment",
	"list_of_param_assignments : list_of_param_assignments COMMA param_assignment",
	"list_of_path_delay_expressions : path_delay_expression",
	"list_of_path_delay_expressions : path_delay_expression COMMA path_delay_expression",
	"list_of_path_delay_expressions : path_delay_expression COMMA path_delay_expression COMMA path_delay_expression",
	"list_of_path_delay_expressions : path_delay_expression COMMA path_delay_expression COMMA path_delay_expression COMMA path_delay_expression COMMA path_delay_expression COMMA path_delay_expression",
	"list_of_path_delay_expressions : path_delay_expression COMMA path_delay_expression COMMA path_delay_expression COMMA path_delay_expression COMMA path_delay_expression COMMA path_delay_expression COMMA path_delay_expression COMMA path_delay_expression COMMA path_delay_expression COMMA path_delay_expression COMMA path_delay_expression COMMA path_delay_expression",
	"list_of_path_inputs : specify_input_terminal_descriptor",
	"list_of_path_outputs : specify_output_terminal_descriptor",
	"list_of_ports : /* empty */",
	"list_of_ports : OPENPAREN port CLOSEPAREN",
	"list_of_port_identifiers : identifier",
	"list_of_port_identifiers : list_of_port_identifiers COMMA identifier",
	"list_of_real_identifiers : identifier",
	"list_of_register_identifiers : register_name",
	"list_of_specparam_assignments : specparam_assignment",
	"long_comment : /* empty */",
	"loop_statement : FOREVER statement",
	"loop_statement : REPEAT OPENPAREN expression CLOSEPAREN statement",
	"loop_statement : WHILE OPENPAREN expression CLOSEPAREN statement",
	"loop_statement : FOR OPENPAREN reg_assignment SEMICOLON expression SEMICOLON reg_assignment CLOSEPAREN statement",
	"mintypmax_expression : expression",
	"mintypmax_expression : expression COLON expression COLON expression",
	"module_declaration : module_keyword identifier list_of_ports SEMICOLON module_item ENDMODULE",
	"module_instance : /* empty */",
	"module_instance : name_of_instance OPENPAREN list_of_module_connections CLOSEPAREN",
	"module_instance : module_instance COMMA name_of_instance OPENPAREN list_of_module_connections CLOSEPAREN",
	"module_instantiation : identifier parameter_value_assignment module_instance SEMICOLON",
	"module_item : /* empty */",
	"module_item : module_item_declaration",
	"module_item : parameter_override",
	"module_item : continuous_assign",
	"module_item : gate_instantiation",
	"module_item : udp_instantiation",
	"module_item : module_instantiation",
	"module_item : specify_block",
	"module_item : initial_construct",
	"module_item : always_construct",
	"module_item : module_item module_item_declaration",
	"module_item : module_item parameter_override",
	"module_item : module_item continuous_assign",
	"module_item : module_item gate_instantiation",
	"module_item : module_item udp_instantiation",
	"module_item : module_item module_instantiation",
	"module_item : module_item specify_block",
	"module_item : module_item initial_construct",
	"module_item : module_item always_construct",
	"module_item_declaration : parameter_declaration",
	"module_item_declaration : input_declaration",
	"module_item_declaration : output_declaration",
	"module_item_declaration : inout_declaration",
	"module_item_declaration : net_declaration",
	"module_item_declaration : reg_declaration",
	"module_item_declaration : integer_declaration",
	"module_item_declaration : real_declaration",
	"module_item_declaration : time_declaration",
	"module_item_declaration : realtime_declaration",
	"module_item_declaration : event_declaration",
	"module_item_declaration : task_declaration",
	"module_item_declaration : function_declaration",
	"module_keyword : MODULE",
	"module_keyword : MACROMODULE",
	"mos_switchtype : NMOS",
	"mos_switchtype : PMOS",
	"mos_switchtype : RNMOS",
	"mos_switchtype : RPMOS",
	"mos_switch_instance : /* empty */",
	"mos_switch_instance : name_of_gate_instance OPENPAREN output_terminal COMMA input_terminal COMMA enable_terminal CLOSEPAREN",
	"mos_switch_instance : mos_switch_instance COMMA name_of_gate_instance OPENPAREN output_terminal COMMA input_terminal COMMA enable_terminal CLOSEPAREN",
	"multiple_concatenation : OPENCURLYBRAC expression OPENCURLYBRAC expression CLOSECURLYBRAC CLOSECURLYBRAC",
	"named_port_connection : /* empty */",
	"named_port_connection : identifier OPENPAREN expression CLOSEPAREN",
	"named_port_connection : named_port_connection COMMA identifier OPENPAREN expression CLOSEPAREN",
	"name_of_gate_instance : /* empty */",
	"name_of_gate_instance : identifier range",
	"name_of_instance : module_instance identifier range",
	"name_of_system_function : DOLLAR identifier",
	"name_of_udp_instance : /* empty */",
	"name_of_udp_instance : identifier range",
	"ncontrol_terminal : expression",
	"net_assignment : /* empty */",
	"net_assignment : net_lvalue EQUAL expression",
	"net_assignment : net_assignment COMMA net_lvalue EQUAL expression",
	"net_declaration : /* empty */",
	"net_declaration : net_type vectored_or_scalared range delay3 list_of_net_identifiers SEMICOLON",
	"net_decl_assignment : identifier EQUAL expression",
	"net_lvalue : identifier",
	"net_lvalue : identifier OPENSQBRAC expression CLOSESQBRAC",
	"net_lvalue : identifier OPENSQBRAC constant_expression COLON constant_expression CLOSESQBRAC",
	"net_lvalue : concatenation",
	"net_type : WIRE",
	"net_type : TRI",
	"net_type : TRI1",
	"net_type : SUPPLY0",
	"net_type : WAND",
	"net_type : TRIAND",
	"net_type : TRI0",
	"net_type : SUPPLY1",
	"net_type : WOR",
	"net_type : TRIOR",
	"next_state : output_symbol",
	"next_state : MINUS",
	"non_blocking_assignment : reg_lvalue LESSOREQUAL delay_or_event_control expression",
	"notify_register : identifier",
	"number : decimal_number",
	"number : octal_number",
	"number : binary_number",
	"number : hex_number",
	"number : real_number",
	"number : unsigned_number",
	"number : ZERO_OR_ONE",
	"n_input_gatetype : AND",
	"n_input_gatetype : NAND",
	"n_input_gatetype : OR",
	"n_input_gatetype : NOR",
	"n_input_gatetype : XOR",
	"n_input_gatetype : XNOR",
	"n_input_gate_instance : name_of_gate_instance OPENPAREN",
	"n_input_gate_instance : name_of_gate_instance OPENPAREN output_terminal COMMA input_terminal_repeat CLOSEPAREN",
	"n_input_gate_instance : n_input_gate_instance",
	"n_input_gate_instance : n_input_gate_instance COMMA name_of_gate_instance OPENPAREN",
	"n_input_gate_instance : n_input_gate_instance COMMA name_of_gate_instance OPENPAREN output_terminal COMMA input_terminal_repeat CLOSEPAREN",
	"n_output_gatetype : /* empty */",
	"n_output_gatetype : BUF",
	"n_output_gatetype : NOT",
	"n_output_gatetype : INV",
	"n_output_gate_instance : name_of_gate_instance OPENPAREN",
	"n_output_gate_instance : name_of_gate_instance OPENPAREN output_terminal COMMA input_terminal CLOSEPAREN",
	"n_output_gate_instance : n_output_gate_instance",
	"n_output_gate_instance : n_output_gate_instance COMMA name_of_gate_instance OPENPAREN",
	"n_output_gate_instance : n_output_gate_instance COMMA name_of_gate_instance OPENPAREN output_terminal COMMA input_terminal CLOSEPAREN",
	"octal_number : size OCTAL_NUMBER",
	"ordered_port_connection : /* empty */",
	"ordered_port_connection : ordered_port_connection COMMA ordered_port_connection",
	"ordered_port_connection : expression",
	"output_declaration : OUTPUT",
	"output_declaration : OUTPUT range list_of_port_identifiers SEMICOLON",
	"output_identifier : identifier",
	"output_port_connection : /* empty */",
	"output_port_connection : expression",
	"output_symbol : ZERO_OR_ONE",
	"output_symbol : EX",
	"output_terminal : IDENTIFIER",
	"output_terminal : IDENTIFIER OPENSQBRAC constant_expression CLOSESQBRAC",
	"output_terminal_repeat : output_terminal",
	"output_terminal_repeat : output_terminal_repeat COMMA output_terminal",
	"parallel_edge_sensitive_path_description : OPENPAREN edge_identifier specify_input_terminal_descriptor DOUBLERIGHTARROW specify_output_terminal_descriptor polarity_operator COLON data_source_expression CLOSEPAREN",
	"parallel_path_description : OPENPAREN specify_input_terminal_descriptor polarity_operator DOUBLERIGHTARROW specify_output_terminal_descriptor CLOSEPAREN",
	"parameter_declaration : PARAMETER list_of_param_assignments SEMICOLON",
	"parameter_override : DEFPARAM list_of_param_assignments SEMICOLON",
	"parameter_value_assignment : /* empty */",
	"parameter_value_assignment : POUND OPENPAREN expression CLOSEPAREN",
	"param_assignment : identifier EQUAL constant_expression",
	"param_assignment : param_assignment COMMA identifier EQUAL constant_expression",
	"par_block : FORK statement JOIN",
	"par_block : FORK COLON identifier block_item_declaration statement JOIN",
	"pass_en_switch_instance : /* empty */",
	"pass_en_switch_instance : name_of_gate_instance OPENPAREN inout_terminal COMMA inout_terminal COMMA enable_terminal CLOSEPAREN",
	"pass_en_switch_instance : pass_en_switch_instance COMMA name_of_gate_instance OPENPAREN inout_terminal COMMA inout_terminal COMMA enable_terminal CLOSEPAREN",
	"pass_en_switchtype : TRANIF0",
	"pass_en_switchtype : TRANIF1",
	"pass_en_switchtype : RTRANIF1",
	"pass_en_switchtype : RTRANIF0",
	"pass_switchtype : TRAN",
	"pass_switchtype : RTRAN",
	"pass_switch_instance : name_of_gate_instance OPENPAREN inout_terminal COMMA inout_terminal CLOSEPAREN",
	"path_declaration : simple_path_declaration SEMICOLON",
	"path_declaration : edge_sensitive_path_declaration SEMICOLON",
	"path_declaration : state_dependent_path_declaration SEMICOLON",
	"path_delay_expression : constant_mintypmax_expression",
	"path_delay_value : list_of_path_delay_expressions",
	"path_delay_value : OPENPAREN list_of_path_delay_expressions CLOSEPAREN",
	"pcontrol_terminal : expression",
	"polarity_operator : /* empty */",
	"polarity_operator : PLUS",
	"polarity_operator : MINUS",
	"port : port_expression",
	"port : identifier OPENPAREN port_expression CLOSEPAREN",
	"port : port COMMA port_expression",
	"port : port COMMA identifier OPENPAREN port_expression CLOSEPAREN",
	"port_expression : /* empty */",
	"port_expression : port_reference",
	"port_expression : OPENCURLYBRAC port_reference CLOSECURLYBRAC",
	"port_reference : /* empty */",
	"port_reference : identifier",
	"port_reference : identifier OPENSQBRAC constant_expression CLOSESQBRAC",
	"port_reference : identifier OPENSQBRAC constant_expression COLON constant_expression CLOSESQBRAC",
	"port_reference : port_reference COMMA identifier",
	"port_reference : port_reference COMMA identifier OPENSQBRAC constant_expression CLOSESQBRAC",
	"port_reference : port_reference COMMA identifier OPENSQBRAC constant_expression COLON constant_expression CLOSESQBRAC",
	"primary : number",
	"primary : identifier",
	"primary : identifier OPENSQBRAC expression CLOSESQBRAC",
	"primary : identifier OPENSQBRAC constant_expression COLON constant_expression CLOSESQBRAC",
	"primary : concatenation",
	"primary : multiple_concatenation",
	"primary : function_call",
	"primary : OPENPAREN mintypmax_expression CLOSEPAREN",
	"procedural_continuous_assignment : ASSIGN reg_assignment SEMICOLON",
	"procedural_continuous_assignment : DEASSIGN reg_lvalue SEMICOLON",
	"procedural_continuous_assignment : FORCE reg_assignment SEMICOLON",
	"procedural_continuous_assignment : FORCE net_assignment SEMICOLON",
	"procedural_continuous_assignment : RELEASE reg_lvalue SEMICOLON",
	"procedural_continuous_assignment : RELEASE net_lvalue SEMICOLON",
	"procedural_timing_control_statement : delay_or_event_control statement_or_null",
	"pulldown_strength : /* empty */",
	"pulldown_strength : OPENPAREN strength0 COMMA strength1 CLOSEPAREN",
	"pulldown_strength : OPENPAREN strength1 COMMA strength0 CLOSEPAREN",
	"pulldown_strength : OPENPAREN strength0 CLOSEPAREN",
	"pullup_strength : /* empty */",
	"pullup_strength : OPENPAREN strength0 COMMA strength1 CLOSEPAREN",
	"pullup_strength : OPENPAREN strength1 COMMA strength0 CLOSEPAREN",
	"pullup_strength : OPENPAREN strength1 CLOSEPAREN",
	"pull_gate_instance : /* empty */",
	"pull_gate_instance : name_of_gate_instance OPENPAREN output_terminal CLOSEPAREN",
	"pull_gate_instance : pull_gate_instance COMMA name_of_gate_instance OPENPAREN output_terminal CLOSEPAREN",
	"pulse_control_specparam : PATHPULSE DOLLAR EQUAL OPENPAREN limit_value CLOSEPAREN SEMICOLON",
	"pulse_control_specparam : PATHPULSE DOLLAR EQUAL OPENPAREN limit_value COMMA limit_value CLOSEPAREN SEMICOLON",
	"pulse_control_specparam : PATHPULSE DOLLAR specify_input_terminal_descriptor DOLLAR specify_output_terminal_descriptor EQUAL limit_value CLOSEPAREN SEMICOLON",
	"pulse_control_specparam : PATHPULSE DOLLAR specify_input_terminal_descriptor DOLLAR specify_output_terminal_descriptor EQUAL limit_value COMMA limit_value CLOSEPAREN SEMICOLON",
	"range : /* empty */",
	"range : OPENSQBRAC constant_expression COLON constant_expression CLOSESQBRAC",
	"range_or_type : /* empty */",
	"range_or_type : range",
	"range_or_type : INTEGER",
	"range_or_type : REAL",
	"range_or_type : REALTIME",
	"range_or_type : TIME",
	"realtime_declaration : REALTIME list_of_real_identifiers SEMICOLON",
	"real_declaration : REAL list_of_real_identifiers SEMICOLON",
	"real_number : sign REAL_NUMBER",
	"register_name : /* empty */",
	"register_name : identifier",
	"register_name : identifier OPENSQBRAC constant_expression COLON constant_expression CLOSESQBRAC",
	"register_name : register_name COMMA identifier",
	"register_name : register_name COMMA identifier OPENSQBRAC constant_expression COLON constant_expression CLOSESQBRAC",
	"reg_assignment : reg_lvalue EQUAL expression",
	"reg_declaration : REG range list_of_register_identifiers SEMICOLON",
	"reg_lvalue : identifier",
	"reg_lvalue : identifier OPENSQBRAC expression OPENSQBRAC",
	"reg_lvalue : identifier OPENSQBRAC constant_expression COLON constant_expression CLOSESQBRAC",
	"reg_lvalue : concatenation",
	"scalar_constant : ZERO_OR_ONE",
	"scalar_constant : ONE_KNOWN_BIT",
	"scalar_constant : KNOWN_BIT",
	"scalar_timing_check_condition : expression",
	"scalar_timing_check_condition : TILDA expression",
	"scalar_timing_check_condition : expression EQUIV_EXPR scalar_constant",
	"sequential_body : udp_initial_statement TABLE sequential_entry ENDTABLE",
	"sequential_entry : /* empty */",
	"sequential_entry : seq_input_list COLON current_state COLON next_state SEMICOLON",
	"sequential_entry : sequential_entry seq_input_list COLON current_state COLON next_state SEMICOLON",
	"seq_block : BEGN COLON identifier block_item_declaration statement END",
	"seq_block : BEGN statement END",
	"seq_input_list : level_input_list",
	"seq_input_list : edge_input_list",
	"short_comment : /* empty */",
	"sign : /* empty */",
	"sign : PLUS",
	"sign : MINUS",
	"simple_identifier : SIMPLE_IDENTIFIER",
	"simple_path_declaration : parallel_path_description EQUAL path_delay_value",
	"simple_path_declaration : full_path_description EQUAL path_delay_value",
	"size : /* empty */",
	"size : unsigned_number",
	"source_text : description",
	"specify_block : SPECIFY specify_item ENDSPECIFY",
	"specify_input_terminal_descriptor : input_identifier",
	"specify_input_terminal_descriptor : input_identifier OPENSQBRAC constant_expression CLOSESQBRAC",
	"specify_input_terminal_descriptor : input_identifier OPENSQBRAC constant_expression COLON constant_expression CLOSESQBRAC",
	"specify_input_terminal_descriptor : specify_input_terminal_descriptor COMMA input_identifier",
	"specify_input_terminal_descriptor : specify_input_terminal_descriptor COMMA input_identifier OPENSQBRAC constant_expression CLOSESQBRAC",
	"specify_input_terminal_descriptor : specify_input_terminal_descriptor COMMA input_identifier OPENSQBRAC constant_expression COLON constant_expression CLOSESQBRAC",
	"specify_item : /* empty */",
	"specify_item : specparam_declaration",
	"specify_item : path_declaration",
	"specify_item : system_timing_check",
	"specify_output_terminal_descriptor : output_identifier",
	"specify_output_terminal_descriptor : output_identifier OPENSQBRAC constant_expression CLOSESQBRAC",
	"specify_output_terminal_descriptor : output_identifier OPENSQBRAC constant_expression COLON constant_expression CLOSESQBRAC",
	"specify_output_terminal_descriptor : specify_output_terminal_descriptor COMMA output_identifier",
	"specify_output_terminal_descriptor : specify_output_terminal_descriptor COMMA output_identifier OPENSQBRAC constant_expression CLOSESQBRAC",
	"specify_output_terminal_descriptor : specify_output_terminal_descriptor COMMA output_identifier OPENSQBRAC constant_expression COLON constant_expression CLOSESQBRAC",
	"specify_terminal_descriptor : specify_input_terminal_descriptor",
	"specify_terminal_descriptor : specify_output_terminal_descriptor",
	"specparam_assignment : /* empty */",
	"specparam_assignment : identifier EQUAL constant_expression",
	"specparam_assignment : pulse_control_specparam",
	"specparam_assignment : specparam_assignment COMMA identifier EQUAL constant_expression",
	"specparam_assignment : specparam_assignment COMMA pulse_control_specparam",
	"specparam_declaration : SPECPARAM list_of_specparam_assignments SEMICOLON",
	"statement : /* empty */",
	"statement : blocking_assignment SEMICOLON",
	"statement : non_blocking_assignment SEMICOLON",
	"statement : procedural_continuous_assignment SEMICOLON",
	"statement : procedural_timing_control_statement",
	"statement : conditional_statement",
	"statement : case_statement",
	"statement : loop_statement",
	"statement : wait_statement",
	"statement : disable_statement",
	"statement : event_trigger",
	"statement : seq_block",
	"statement : par_block",
	"statement : task_enable",
	"statement : system_task_enable",
	"statement : statement blocking_assignment SEMICOLON",
	"statement : statement non_blocking_assignment SEMICOLON",
	"statement : statement procedural_continuous_assignment SEMICOLON",
	"statement : statement procedural_timing_control_statement",
	"statement : statement conditional_statement",
	"statement : statement case_statement",
	"statement : statement loop_statement",
	"statement : statement wait_statement",
	"statement : statement disable_statement",
	"statement : statement event_trigger",
	"statement : statement seq_block",
	"statement : statement par_block",
	"statement : statement task_enable",
	"statement : statement system_task_enable",
	"statement_or_null : statement",
	"statement_or_null : SEMICOLON",
	"state_dependent_path_declaration : IF OPENPAREN expression CLOSEPAREN simple_path_declaration",
	"state_dependent_path_declaration : IF OPENPAREN expression CLOSEPAREN edge_sensitive_path_declaration",
	"state_dependent_path_declaration : IFNONE simple_path_declaration",
	"strength0 : SUPPLY0",
	"strength0 : STRONG0",
	"strength0 : PULL0",
	"strength0 : WEAK0",
	"strength1 : SUPPLY1",
	"strength1 : STRONG1",
	"strength1 : PULL1",
	"strength1 : WEAK1",
	"string : STRING",
	"system_task_enable : system_task_name SEMICOLON",
	"system_task_enable : system_task_name OPENPAREN expression CLOSEPAREN SEMICOLON",
	"system_task_name : DOLLAR identifier",
	"system_timing_check : DOLLAR SETUP OPENPAREN timing_check_event COMMA timing_check_event COMMA timing_check_limit CLOSEPAREN SEMICOLON",
	"system_timing_check : DOLLAR SETUP OPENPAREN timing_check_event COMMA timing_check_event COMMA timing_check_limit COMMA notify_register CLOSEPAREN SEMICOLON",
	"system_timing_check : DOLLAR HOLD OPENPAREN timing_check_event COMMA timing_check_event COMMA timing_check_limit CLOSEPAREN SEMICOLON",
	"system_timing_check : DOLLAR HOLD OPENPAREN timing_check_event COMMA timing_check_event COMMA timing_check_limit COMMA notify_register CLOSEPAREN SEMICOLON",
	"system_timing_check : DOLLAR PERIOD OPENPAREN controlled_timing_check_event COMMA timing_check_limit CLOSEPAREN SEMICOLON",
	"system_timing_check : DOLLAR PERIOD OPENPAREN controlled_timing_check_event COMMA timing_check_limit COMMA notify_register CLOSEPAREN SEMICOLON",
	"system_timing_check : DOLLAR WIDTH OPENPAREN controlled_timing_check_event COMMA timing_check_limit COMMA constant_expression CLOSEPAREN SEMICOLON",
	"system_timing_check : DOLLAR WIDTH OPENPAREN controlled_timing_check_event COMMA timing_check_limit COMMA constant_expression COMMA notify_register CLOSEPAREN SEMICOLON",
	"system_timing_check : DOLLAR SKEW OPENPAREN timing_check_event COMMA timing_check_event COMMA timing_check_limit CLOSEPAREN SEMICOLON",
	"system_timing_check : DOLLAR SKEW OPENPAREN timing_check_event COMMA timing_check_event COMMA timing_check_limit COMMA notify_register CLOSEPAREN SEMICOLON",
	"system_timing_check : DOLLAR RECOVERY OPENPAREN controlled_timing_check_event COMMA timing_check_event COMMA timing_check_limit CLOSEPAREN SEMICOLON",
	"system_timing_check : DOLLAR RECOVERY OPENPAREN controlled_timing_check_event COMMA timing_check_event COMMA timing_check_limit COMMA notify_register CLOSEPAREN SEMICOLON",
	"system_timing_check : DOLLAR SETUPHOLD OPENPAREN timing_check_event COMMA timing_check_event COMMA timing_check_limit COMMA timing_check_limit CLOSEPAREN SEMICOLON",
	"system_timing_check : DOLLAR SETUPHOLD OPENPAREN timing_check_event COMMA timing_check_event COMMA timing_check_limit COMMA timing_check_limit COMMA notify_register CLOSEPAREN SEMICOLON",
	"task_argument_declaration : /* empty */",
	"task_argument_declaration : block_item_declaration",
	"task_argument_declaration : output_declaration",
	"task_argument_declaration : inout_declaration",
	"task_argument_declaration : task_argument_declaration block_item_declaration",
	"task_argument_declaration : task_argument_declaration output_declaration",
	"task_argument_declaration : task_argument_declaration inout_declaration",
	"task_declaration : TASK identifier SEMICOLON task_argument_declaration statement_or_null ENDTASK",
	"task_enable : identifier OPENPAREN expression CLOSEPAREN SEMICOLON",
	"time_declaration : TIME list_of_register_identifiers SEMICOLON",
	"timing_check_condition : scalar_timing_check_condition",
	"timing_check_condition : OPENPAREN scalar_timing_check_condition CLOSEPAREN",
	"timing_check_event : timing_check_event_control specify_terminal_descriptor",
	"timing_check_event : timing_check_event_control specify_terminal_descriptor TRIAMPERSAND timing_check_condition",
	"timing_check_event_control : /* empty */",
	"timing_check_event_control : POSEDGE",
	"timing_check_event_control : NEGEDGE",
	"timing_check_event_control : edge_control_specifier",
	"timing_check_limit : expression",
	"udp_body : combinational_body",
	"udp_body : sequential_body",
	"udp_declaration : PRIMITIVE identifier OPENPAREN udp_port_list CLOSEPAREN SEMICOLON udp_port_declaration udp_body ENDPRIMITIVE",
	"udp_initial_statement : /* empty */",
	"udp_initial_statement : INITL identifier EQUAL init_val SEMICOLON",
	"udp_instance : /* empty */",
	"udp_instance : name_of_udp_instance OPENPAREN output_port_connection COMMA input_port_connection CLOSEPAREN",
	"udp_instance : udp_instance COMMA name_of_udp_instance OPENPAREN output_port_connection COMMA input_port_connection CLOSEPAREN",
	"udp_instantiation : identifier drive_strength delay2 udp_instance SEMICOLON",
	"udp_port_declaration : /* empty */",
	"udp_port_declaration : output_declaration",
	"udp_port_declaration : input_declaration",
	"udp_port_declaration : reg_declaration",
	"udp_port_declaration : udp_port_declaration output_declaration",
	"udp_port_declaration : udp_port_declaration input_declaration",
	"udp_port_declaration : udp_port_declaration reg_declaration",
	"udp_port_list : identifier COMMA identifier",
	"unary_operator : PLUS",
	"unary_operator : MINUS",
	"unary_operator : OPERATOR",
	"unary_operator : TILDA",
	"unary_operator : UNARY_OPERATOR",
	"unsigned_number : EDGE_OR_UNSIGNED",
	"unsigned_number : ZERO_OR_ONE",
	"unsigned_number : UNSIGNED_NUMBER",
	"vectored_or_scalared : /* empty */",
	"vectored_or_scalared : VECTORED",
	"vectored_or_scalared : SCALARED",
	"wait_statement : WAIT OPENPAREN expression CLOSEPAREN statement_or_null",
};
#endif /* YYDEBUG */
# line	1 "/usr/ccs/bin/yaccpar"
/*
 * Copyright (c) 1993 by Sun Microsystems, Inc.
 */

#pragma ident	"@(#)yaccpar	6.15	97/12/08 SMI"

/*
** Skeleton parser driver for yacc output
*/

/*
** yacc user known macros and defines
*/
#define YYERROR		goto yyerrlab
#define YYACCEPT	return(0)
#define YYABORT		return(1)
#define YYBACKUP( newtoken, newvalue )\
{\
	if ( yychar >= 0 || ( yyr2[ yytmp ] >> 1 ) != 1 )\
	{\
		yyerror( "syntax error - cannot backup" );\
		goto yyerrlab;\
	}\
	yychar = newtoken;\
	yystate = *yyps;\
	yylval = newvalue;\
	goto yynewstate;\
}
#define YYRECOVERING()	(!!yyerrflag)
#define YYNEW(type)	malloc(sizeof(type) * yynewmax)
#define YYCOPY(to, from, type) \
	(type *) memcpy(to, (char *) from, yymaxdepth * sizeof (type))
#define YYENLARGE( from, type) \
	(type *) realloc((char *) from, yynewmax * sizeof(type))
#ifndef YYDEBUG
#	define YYDEBUG	1	/* make debugging available */
#endif

/*
** user known globals
*/
int yydebug;			/* set to 1 to get debugging */

/*
** driver internal defines
*/
#define YYFLAG		(-10000000)

/*
** global variables used by the parser
*/
YYSTYPE *yypv;			/* top of value stack */
int *yyps;			/* top of state stack */

int yystate;			/* current state */
int yytmp;			/* extra var (lasts between blocks) */

int yynerrs;			/* number of errors */
int yyerrflag;			/* error recovery flag */
int yychar;			/* current input token number */



#ifdef YYNMBCHARS
#define YYLEX()		yycvtok(yylex())
/*
** yycvtok - return a token if i is a wchar_t value that exceeds 255.
**	If i<255, i itself is the token.  If i>255 but the neither 
**	of the 30th or 31st bit is on, i is already a token.
*/
#if defined(__STDC__) || defined(__cplusplus)
int yycvtok(int i)
#else
int yycvtok(i) int i;
#endif
{
	int first = 0;
	int last = YYNMBCHARS - 1;
	int mid;
	wchar_t j;

	if(i&0x60000000){/*Must convert to a token. */
		if( yymbchars[last].character < i ){
			return i;/*Giving up*/
		}
		while ((last>=first)&&(first>=0)) {/*Binary search loop*/
			mid = (first+last)/2;
			j = yymbchars[mid].character;
			if( j==i ){/*Found*/ 
				return yymbchars[mid].tvalue;
			}else if( j<i ){
				first = mid + 1;
			}else{
				last = mid -1;
			}
		}
		/*No entry in the table.*/
		return i;/* Giving up.*/
	}else{/* i is already a token. */
		return i;
	}
}
#else/*!YYNMBCHARS*/
#define YYLEX()		yylex()
#endif/*!YYNMBCHARS*/

/*
** yyparse - return 0 if worked, 1 if syntax error not recovered from
*/
#if defined(__STDC__) || defined(__cplusplus)
int yyparse(void)
#else
int yyparse()
#endif
{
	register YYSTYPE *yypvt = 0;	/* top of value stack for $vars */

#if defined(__cplusplus) || defined(lint)
/*
	hacks to please C++ and lint - goto's inside
	switch should never be executed
*/
	static int __yaccpar_lint_hack__ = 0;
	switch (__yaccpar_lint_hack__)
	{
		case 1: goto yyerrlab;
		case 2: goto yynewstate;
	}
#endif

	/*
	** Initialize externals - yyparse may be called more than once
	*/
	yypv = &yyv[-1];
	yyps = &yys[-1];
	yystate = 0;
	yytmp = 0;
	yynerrs = 0;
	yyerrflag = 0;
	yychar = -1;

#if YYMAXDEPTH <= 0
	if (yymaxdepth <= 0)
	{
		if ((yymaxdepth = YYEXPAND(0)) <= 0)
		{
			yyerror("yacc initialization error");
			YYABORT;
		}
	}
#endif

	{
		register YYSTYPE *yy_pv;	/* top of value stack */
		register int *yy_ps;		/* top of state stack */
		register int yy_state;		/* current state */
		register int  yy_n;		/* internal state number info */
	goto yystack;	/* moved from 6 lines above to here to please C++ */

		/*
		** get globals into registers.
		** branch to here only if YYBACKUP was called.
		*/
	yynewstate:
		yy_pv = yypv;
		yy_ps = yyps;
		yy_state = yystate;
		goto yy_newstate;

		/*
		** get globals into registers.
		** either we just started, or we just finished a reduction
		*/
	yystack:
		yy_pv = yypv;
		yy_ps = yyps;
		yy_state = yystate;

		/*
		** top of for (;;) loop while no reductions done
		*/
	yy_stack:
		/*
		** put a state and value onto the stacks
		*/
#if YYDEBUG
		/*
		** if debugging, look up token value in list of value vs.
		** name pairs.  0 and negative (-1) are special values.
		** Note: linear search is used since time is not a real
		** consideration while debugging.
		*/
		if ( yydebug )
		{
			register int yy_i;

			printf( "State %d, token ", yy_state );
			if ( yychar == 0 )
				printf( "end-of-file\n" );
			else if ( yychar < 0 )
				printf( "-none-\n" );
			else
			{
				for ( yy_i = 0; yytoks[yy_i].t_val >= 0;
					yy_i++ )
				{
					if ( yytoks[yy_i].t_val == yychar )
						break;
				}
				printf( "%s\n", yytoks[yy_i].t_name );
			}
		}
#endif /* YYDEBUG */
		if ( ++yy_ps >= &yys[ yymaxdepth ] )	/* room on stack? */
		{
			/*
			** reallocate and recover.  Note that pointers
			** have to be reset, or bad things will happen
			*/
			long yyps_index = (yy_ps - yys);
			long yypv_index = (yy_pv - yyv);
			long yypvt_index = (yypvt - yyv);
			int yynewmax;
#ifdef YYEXPAND
			yynewmax = YYEXPAND(yymaxdepth);
#else
			yynewmax = 2 * yymaxdepth;	/* double table size */
			if (yymaxdepth == YYMAXDEPTH)	/* first time growth */
			{
				char *newyys = (char *)YYNEW(int);
				char *newyyv = (char *)YYNEW(YYSTYPE);
				if (newyys != 0 && newyyv != 0)
				{
					yys = YYCOPY(newyys, yys, int);
					yyv = YYCOPY(newyyv, yyv, YYSTYPE);
				}
				else
					yynewmax = 0;	/* failed */
			}
			else				/* not first time */
			{
				yys = YYENLARGE(yys, int);
				yyv = YYENLARGE(yyv, YYSTYPE);
				if (yys == 0 || yyv == 0)
					yynewmax = 0;	/* failed */
			}
#endif
			if (yynewmax <= yymaxdepth)	/* tables not expanded */
			{
				yyerror( "yacc stack overflow" );
				YYABORT;
			}
			yymaxdepth = yynewmax;

			yy_ps = yys + yyps_index;
			yy_pv = yyv + yypv_index;
			yypvt = yyv + yypvt_index;
		}
		*yy_ps = yy_state;
		*++yy_pv = yyval;

		/*
		** we have a new state - find out what to do
		*/
	yy_newstate:
		if ( ( yy_n = yypact[ yy_state ] ) <= YYFLAG )
			goto yydefault;		/* simple state */
#if YYDEBUG
		/*
		** if debugging, need to mark whether new token grabbed
		*/
		yytmp = yychar < 0;
#endif
		if ( ( yychar < 0 ) && ( ( yychar = YYLEX() ) < 0 ) )
			yychar = 0;		/* reached EOF */
#if YYDEBUG
		if ( yydebug && yytmp )
		{
			register int yy_i;

			printf( "Received token " );
			if ( yychar == 0 )
				printf( "end-of-file\n" );
			else if ( yychar < 0 )
				printf( "-none-\n" );
			else
			{
				for ( yy_i = 0; yytoks[yy_i].t_val >= 0;
					yy_i++ )
				{
					if ( yytoks[yy_i].t_val == yychar )
						break;
				}
				printf( "%s\n", yytoks[yy_i].t_name );
			}
		}
#endif /* YYDEBUG */
		if ( ( ( yy_n += yychar ) < 0 ) || ( yy_n >= YYLAST ) )
			goto yydefault;
		if ( yychk[ yy_n = yyact[ yy_n ] ] == yychar )	/*valid shift*/
		{
			yychar = -1;
			yyval = yylval;
			yy_state = yy_n;
			if ( yyerrflag > 0 )
				yyerrflag--;
			goto yy_stack;
		}

	yydefault:
		if ( ( yy_n = yydef[ yy_state ] ) == -2 )
		{
#if YYDEBUG
			yytmp = yychar < 0;
#endif
			if ( ( yychar < 0 ) && ( ( yychar = YYLEX() ) < 0 ) )
				yychar = 0;		/* reached EOF */
#if YYDEBUG
			if ( yydebug && yytmp )
			{
				register int yy_i;

				printf( "Received token " );
				if ( yychar == 0 )
					printf( "end-of-file\n" );
				else if ( yychar < 0 )
					printf( "-none-\n" );
				else
				{
					for ( yy_i = 0;
						yytoks[yy_i].t_val >= 0;
						yy_i++ )
					{
						if ( yytoks[yy_i].t_val
							== yychar )
						{
							break;
						}
					}
					printf( "%s\n", yytoks[yy_i].t_name );
				}
			}
#endif /* YYDEBUG */
			/*
			** look through exception table
			*/
			{
				register const int *yyxi = yyexca;

				while ( ( *yyxi != -1 ) ||
					( yyxi[1] != yy_state ) )
				{
					yyxi += 2;
				}
				while ( ( *(yyxi += 2) >= 0 ) &&
					( *yyxi != yychar ) )
					;
				if ( ( yy_n = yyxi[1] ) < 0 )
					YYACCEPT;
			}
		}

		/*
		** check for syntax error
		*/
		if ( yy_n == 0 )	/* have an error */
		{
			/* no worry about speed here! */
			switch ( yyerrflag )
			{
			case 0:		/* new error */
				yyerror( "syntax error" );
				goto skip_init;
			yyerrlab:
				/*
				** get globals into registers.
				** we have a user generated syntax type error
				*/
				yy_pv = yypv;
				yy_ps = yyps;
				yy_state = yystate;
			skip_init:
				yynerrs++;
				/* FALLTHRU */
			case 1:
			case 2:		/* incompletely recovered error */
					/* try again... */
				yyerrflag = 3;
				/*
				** find state where "error" is a legal
				** shift action
				*/
				while ( yy_ps >= yys )
				{
					yy_n = yypact[ *yy_ps ] + YYERRCODE;
					if ( yy_n >= 0 && yy_n < YYLAST &&
						yychk[yyact[yy_n]] == YYERRCODE)					{
						/*
						** simulate shift of "error"
						*/
						yy_state = yyact[ yy_n ];
						goto yy_stack;
					}
					/*
					** current state has no shift on
					** "error", pop stack
					*/
#if YYDEBUG
#	define _POP_ "Error recovery pops state %d, uncovers state %d\n"
					if ( yydebug )
						printf( _POP_, *yy_ps,
							yy_ps[-1] );
#	undef _POP_
#endif
					yy_ps--;
					yy_pv--;
				}
				/*
				** there is no state on stack with "error" as
				** a valid shift.  give up.
				*/
				YYABORT;
			case 3:		/* no shift yet; eat a token */
#if YYDEBUG
				/*
				** if debugging, look up token in list of
				** pairs.  0 and negative shouldn't occur,
				** but since timing doesn't matter when
				** debugging, it doesn't hurt to leave the
				** tests here.
				*/
				if ( yydebug )
				{
					register int yy_i;

					printf( "Error recovery discards " );
					if ( yychar == 0 )
						printf( "token end-of-file\n" );
					else if ( yychar < 0 )
						printf( "token -none-\n" );
					else
					{
						for ( yy_i = 0;
							yytoks[yy_i].t_val >= 0;
							yy_i++ )
						{
							if ( yytoks[yy_i].t_val
								== yychar )
							{
								break;
							}
						}
						printf( "token %s\n",
							yytoks[yy_i].t_name );
					}
				}
#endif /* YYDEBUG */
				if ( yychar == 0 )	/* reached EOF. quit */
					YYABORT;
				yychar = -1;
				goto yy_newstate;
			}
		}/* end if ( yy_n == 0 ) */
		/*
		** reduction by production yy_n
		** put stack tops, etc. so things right after switch
		*/
#if YYDEBUG
		/*
		** if debugging, print the string that is the user's
		** specification of the reduction which is just about
		** to be done.
		*/
		if ( yydebug )
			printf( "Reduce by (%d) \"%s\"\n",
				yy_n, yyreds[ yy_n ] );
#endif
		yytmp = yy_n;			/* value to switch over */
		yypvt = yy_pv;			/* $vars top of value stack */
		/*
		** Look in goto table for next state
		** Sorry about using yy_state here as temporary
		** register variable, but why not, if it works...
		** If yyr2[ yy_n ] doesn't have the low order bit
		** set, then there is no action to be done for
		** this reduction.  So, no saving & unsaving of
		** registers done.  The only difference between the
		** code just after the if and the body of the if is
		** the goto yy_stack in the body.  This way the test
		** can be made before the choice of what to do is needed.
		*/
		{
			/* length of production doubled with extra bit */
			register int yy_len = yyr2[ yy_n ];

			if ( !( yy_len & 01 ) )
			{
				yy_len >>= 1;
				yyval = ( yy_pv -= yy_len )[1];	/* $$ = $1 */
				yy_state = yypgo[ yy_n = yyr1[ yy_n ] ] +
					*( yy_ps -= yy_len ) + 1;
				if ( yy_state >= YYLAST ||
					yychk[ yy_state =
					yyact[ yy_state ] ] != -yy_n )
				{
					yy_state = yyact[ yypgo[ yy_n ] ];
				}
				goto yy_stack;
			}
			yy_len >>= 1;
			yyval = ( yy_pv -= yy_len )[1];	/* $$ = $1 */
			yy_state = yypgo[ yy_n = yyr1[ yy_n ] ] +
				*( yy_ps -= yy_len ) + 1;
			if ( yy_state >= YYLAST ||
				yychk[ yy_state = yyact[ yy_state ] ] != -yy_n )
			{
				yy_state = yyact[ yypgo[ yy_n ] ];
			}
		}
					/* save until reenter driver code */
		yystate = yy_state;
		yyps = yy_ps;
		yypv = yy_pv;
	}
	/*
	** code supplied by user is placed in this switch
	*/
	switch( yytmp )
	{
		
case 71:
# line 616 "verilog.yacc"
{elemlist->delay = 0;} break;
case 72:
# line 618 "verilog.yacc"
{delay_index++;
		} break;
case 73:
# line 621 "verilog.yacc"
{delay_index++;		      
		} break;
case 76:
# line 628 "verilog.yacc"
{delay_index++;
		} break;
case 77:
# line 631 "verilog.yacc"
{delay_index++;
		} break;
case 87:
# line 651 "verilog.yacc"
{if(yypvt[-0].n == 0) elemlist->delay = 0;	/*get delay if != 0*/
		 else {
			x=0;
		 	for(i=1; i<delay_index; i++){ 		
		   	  if(delay_table[i].rise == yypvt[-0].n && delay_table[i].fall == yypvt[-0].n){
			    elemlist->delay = i;
			    x++;				/*set to delay index in delay table*/
			  }					/*if delay already exists*/
			}
			if(!x){
			  delay_table[delay_index].rise = yypvt[-0].n;	/*create new delay in delay table*/
			  delay_table[delay_index].fall = yypvt[-0].n;	/*if delay does not exist*/
			  elemlist->delay = delay_index;
			}
		      }
		} break;
case 89:
# line 673 "verilog.yacc"
{if(yypvt[-0].n == 0) elemlist->delay = 0;
		 else if(!x){
		   delay_table[delay_index].fall = yypvt[-0].n;	/*if delay does not exist*/
		   delay_index++;
		   }
		} break;
case 99:
# line 695 "verilog.yacc"
{elemlist->delay = 0;} break;
case 100:
# line 697 "verilog.yacc"
{delay_index++;
		} break;
case 101:
# line 700 "verilog.yacc"
{delay_index++;		      
		} break;
case 104:
# line 707 "verilog.yacc"
{delay_index++;
		} break;
case 105:
# line 710 "verilog.yacc"
{delay_index++;
		} break;
case 108:
# line 717 "verilog.yacc"
{elemlist->position = INTERNAL;		/*set gate parameters*/
			 elemlist->logictype = E_LOGIC_GATE;	
			 HT_TAIL(elemlist,&ehead,&etail);
			 elemcount++;
			 IDnum++;} break;
case 110:
# line 727 "verilog.yacc"
{elemlist = MALLOC_TYPE(struct ELEM);
			elemlist->gatetype = etail->gatetype;
		  	elemlist->inputs = elemlist->outputs = 0; 
			} break;
case 111:
# line 732 "verilog.yacc"
{elemlist->position = INTERNAL;		/*set gate parameters*/
			 elemlist->logictype = E_LOGIC_GATE;	
			 HT_TAIL(elemlist,&ehead,&etail);
			 elemcount++;
			 IDnum++;} break;
case 116:
# line 749 "verilog.yacc"
{modulecount++;} break;
case 125:
# line 769 "verilog.yacc"
{position = INP;} break;
case 127:
# line 772 "verilog.yacc"
{position = OUTP;} break;
case 129:
# line 778 "verilog.yacc"
{elemlist = MALLOC_TYPE(struct ELEM);
		 elemlist->gatetype = D_FLIP_FLOP;		/*set gatetype*/
		 elemlist->inputs = elemlist->outputs = 0; 
		} break;
case 130:
# line 785 "verilog.yacc"
{elemlist->position = INTERNAL;		/*set dff parameters*/
			 elemlist->logictype = E_LOGIC_GATE;	
			 HT_TAIL(elemlist,&ehead,&etail);
			 elemcount++;
			 IDnum++;} break;
case 132:
# line 797 "verilog.yacc"
{elemlist->position = INTERNAL;		/*set dff parameters*/
			 elemlist->logictype = E_LOGIC_GATE;	
			 HT_TAIL(elemlist,&ehead,&etail);
			 elemcount++;
			 IDnum++;} break;
case 134:
# line 811 "verilog.yacc"
{Is_in_list=FALSE;
			 for(wirelist=whead; wirelist; wirelist=wirelist->next)
			        if(!strcmp(wirelist->name,yypvt[-0].txt)){
			           Is_in_list = TRUE;
				   break;
				}
			 if(!Is_in_list){
			   wirelist = MALLOC_TYPE(struct Wire);
			   wirelist->fanin = wirelist->fanout = 0;
			   wirelist->name = yypvt[-0].txt;
			 }
			 wirelist->fanout++;
			 etail->inputs++;
			 if(!Is_in_list) HT_TAIL(wirelist, &whead, &wtail);
			 wirelist->conn = MALLOC_TYPE(struct CONNECTION);
			 wirelist->conn->ept = etail;
			 elemlist->conn = MALLOC_TYPE(struct CONNECTION);
			 elemlist->conn->wpt = wirelist;
			 HT_HEAD(elemlist->conn, &elemlist->cinhead, &elemlist->cintail);   /*<-link at head instd*/
			 HT_TAIL(wirelist->conn, &wirelist->couthead, &wirelist->couttail); /*of tail to resolve  */
			} break;
case 210:
# line 982 "verilog.yacc"
{printf("");} break;
case 211:
# line 984 "verilog.yacc"
{printf("");} break;
case 212:
# line 986 "verilog.yacc"
{printf("");} break;
case 213:
# line 988 "verilog.yacc"
{printf("");} break;
case 220:
# line 1006 "verilog.yacc"
{position = BIDIR;} break;
case 224:
# line 1015 "verilog.yacc"
{position = INP;} break;
case 230:
# line 1028 "verilog.yacc"
{Is_in_list=FALSE;
			 for(wirelist=whead; wirelist; wirelist=wirelist->next)
			        if(!strcmp(wirelist->name,yypvt[-0].txt)){
			           Is_in_list = TRUE;
				   break;
				}
			 if(!Is_in_list){
			   wirelist = MALLOC_TYPE(struct Wire);
			   wirelist->fanin = wirelist->fanout = 0;
			   wirelist->name = yypvt[-0].txt;
			   wirelist->link_bit = 0;
			 }
			 wirelist->fanout++;
			 elemlist->inputs++;
			 if(!Is_in_list) HT_TAIL(wirelist, &whead, &wtail);
			 wirelist->conn = MALLOC_TYPE(struct CONNECTION);
			 wirelist->conn->ept = elemlist;
			 elemlist->conn = MALLOC_TYPE(struct CONNECTION);
			 elemlist->conn->wpt = wirelist;
			 HT_TAIL(elemlist->conn, &elemlist->cinhead, &elemlist->cintail);
			 HT_TAIL(wirelist->conn, &wirelist->couthead, &wirelist->couttail);
 			} break;
case 250:
# line 1090 "verilog.yacc"
{if(elemlist->delay!=0){
				    elemlist->name = yypvt[-0].txt;
				    elemlist->sim_lev = 0;
				    elemcount++;
				    HT_TAIL(elemlist, &ehead, &etail); 
				    wirelist = MALLOC_TYPE(struct Wire);
			  	    wirelist->name = yypvt[-0].txt;
				    wirelist->fanin = wirelist->fanout = 0;
				    wirelist->elem = elemlist;
				    elemlist->cinhead = NULL;
				    HT_TAIL(wirelist,&whead,&wtail);
				    }
				 } break;
case 251:
# line 1104 "verilog.yacc"
{if(elemlist->delay!=0){
				    elemlist->name = yypvt[-0].txt;
				    elemlist->sim_lev = 0;
				    elemcount++;
				    HT_TAIL(elemlist, &ehead, &etail); 
				    wirelist = MALLOC_TYPE(struct Wire);
			  	    wirelist->name = yypvt[-0].txt;
				    wirelist->fanin = wirelist->fanout = 0;
				    wirelist->elem = elemlist;
				    elemlist->cinhead = NULL;
				    HT_TAIL(wirelist,&whead,&wtail);
				    }
				 } break;
case 263:
# line 1152 "verilog.yacc"
{elemlist = MALLOC_TYPE(struct ELEM);
				 elemlist->index = IDnum;	/*set input and output ports*/
				 elemlist->logictype = E_WIRE;	/*with wire parameters*/
				 elemlist->name = yypvt[-0].txt;
				  elemlist->inputs = 1;
				  elemlist->outputs = 1;
				 elemlist->position = position;
				 HT_TAIL(elemlist,&ehead,&etail); 
				 wirelist = MALLOC_TYPE(struct Wire);
			  	  wirelist->name = yypvt[-0].txt;
				 wirelist->fanin = wirelist->fanout = 0;
				 if(wirelist->elem==NULL) wirelist->elem = elemlist;
				   elemlist->cinhead = NULL;
				 HT_TAIL(wirelist,&whead,&wtail);
				 if(position == INP) {
				   PIs++;
			 	   elemlist->sim_lev = 1;
				   elemlist->cinhead = NULL;
				 }
				 else if(position == BIDIR) BiDirectionals++;
				 else if(position == OUTP) POs++;	
				 elemcount++;
				 IDnum++;} break;
case 264:
# line 1176 "verilog.yacc"
{elemlist = MALLOC_TYPE(struct ELEM);
				 elemlist->index = IDnum;	/*set input and output ports*/
				 elemlist->logictype = E_WIRE;	/*with wire parameters*/
				 elemlist->name = yypvt[-0].txt;
				  elemlist->inputs = 1;
				  elemlist->outputs = 1;
				 elemlist->position = position;
				 HT_TAIL(elemlist,&ehead,&etail); 
				 wirelist = MALLOC_TYPE(struct Wire);
			  	  wirelist->name = yypvt[-0].txt;
				 wirelist->fanin = wirelist->fanout = 0;
				 if(wirelist->elem==NULL) wirelist->elem = elemlist;
				   elemlist->cinhead = NULL;
				 HT_TAIL(wirelist,&whead,&wtail);
				 if(position == INP) {
				   PIs++;
			 	   elemlist->sim_lev = 1;
				   elemlist->cinhead = NULL;
				 }
				 else if(position == BIDIR) BiDirectionals++;
				 else if(position == OUTP) POs++;		
				 elemcount++;
				 IDnum++;} break;
case 312:
# line 1274 "verilog.yacc"
{modulecount++;} break;
case 326:
# line 1304 "verilog.yacc"
{
				elemlist->name = yypvt[-1].txt; 		/*get element name and index*/
				elemlist->index = IDnum;} break;
case 342:
# line 1342 "verilog.yacc"
{elemlist = MALLOC_TYPE(struct ELEM);
		 elemlist->logictype = E_LOGIC_GATE;
		 elemlist->gatetype = DELAYED_WIRE;
		 elemlist->inputs = elemlist->outputs = 1; 	
		 elemlist->delay = 0;
		} break;
case 363:
# line 1379 "verilog.yacc"
{elemlist = MALLOC_TYPE(struct ELEM);
			elemlist->gatetype = AND_GATE;	
		 	elemlist->inputs = elemlist->outputs = 0; /*For each gate type, assign a value*/
			} break;
case 364:
# line 1384 "verilog.yacc"
{elemlist = MALLOC_TYPE(struct ELEM);
			elemlist->gatetype = NAND_GATE;
		  	elemlist->inputs = elemlist->outputs = 0; 
			} break;
case 365:
# line 1389 "verilog.yacc"
{elemlist = MALLOC_TYPE(struct ELEM);
			elemlist->gatetype = OR_GATE;
		  	elemlist->inputs = elemlist->outputs = 0; 
			} break;
case 366:
# line 1394 "verilog.yacc"
{elemlist = MALLOC_TYPE(struct ELEM);
			elemlist->gatetype = NOR_GATE;
		  	elemlist->inputs = elemlist->outputs = 0; 
			} break;
case 367:
# line 1399 "verilog.yacc"
{elemlist = MALLOC_TYPE(struct ELEM);
			elemlist->gatetype = XOR_GATE;
		  	elemlist->inputs = elemlist->outputs = 0; 
			} break;
case 368:
# line 1404 "verilog.yacc"
{elemlist = MALLOC_TYPE(struct ELEM);
			elemlist->gatetype = XNOR_GATE;
		  	elemlist->inputs = elemlist->outputs = 0; 
			} break;
case 369:
# line 1411 "verilog.yacc"
{elemlist->position = INTERNAL;		/*set gate parameters*/
				 elemlist->logictype = E_LOGIC_GATE;
				 HT_TAIL(elemlist,&ehead,&etail); 
				elemcount++;
				IDnum++;} break;
case 371:
# line 1421 "verilog.yacc"
{elemlist = MALLOC_TYPE(struct ELEM);
				 elemlist->gatetype = etail->gatetype;
		  		 elemlist->inputs = elemlist->outputs = 0; 
				} break;
case 372:
# line 1426 "verilog.yacc"
{elemlist->position = INTERNAL;		/*set gate parameters*/
				 elemlist->logictype = E_LOGIC_GATE;
				 HT_TAIL(elemlist,&ehead,&etail); 
				elemcount++;
				IDnum++;} break;
case 375:
# line 1439 "verilog.yacc"
{elemlist = MALLOC_TYPE(struct ELEM);
			elemlist->gatetype = BUFFER;
		  	elemlist->inputs = elemlist->outputs = 0; 	/*for each gate type, assign*/
			} break;
case 376:
# line 1444 "verilog.yacc"
{elemlist = MALLOC_TYPE(struct ELEM);
			elemlist->gatetype = INVERTER;
		  	elemlist->inputs = elemlist->outputs = 0; 
			} break;
case 377:
# line 1449 "verilog.yacc"
{elemlist = MALLOC_TYPE(struct ELEM);
			elemlist->gatetype = INVERTER;
		  	elemlist->inputs = elemlist->outputs = 0; 
			} break;
case 378:
# line 1456 "verilog.yacc"
{elemlist->position = INTERNAL;		/*set gate parameters*/
				 elemlist->logictype = E_LOGIC_GATE;
				 HT_TAIL(elemlist,&ehead,&etail); 
				elemcount++;
				IDnum++;} break;
case 380:
# line 1465 "verilog.yacc"
{elemlist = MALLOC_TYPE(struct ELEM);
				 elemlist->gatetype = etail->gatetype;
		  		 elemlist->inputs = elemlist->outputs = 0; 
				} break;
case 381:
# line 1470 "verilog.yacc"
{elemlist->position = INTERNAL;		/*set gate parameters*/
				 elemlist->logictype = E_LOGIC_GATE;
				 HT_TAIL(elemlist,&ehead,&etail); 
				elemcount++;
				IDnum++;} break;
case 387:
# line 1489 "verilog.yacc"
{position = OUTP;} break;
case 394:
# line 1505 "verilog.yacc"
{Is_in_list=FALSE;
			 for(wirelist=whead; wirelist; wirelist=wirelist->next)
			        if(!strcmp(wirelist->name,yypvt[-0].txt)){
			           Is_in_list = TRUE;
				   break;
				}
			 if(!Is_in_list){
			   wirelist = MALLOC_TYPE(struct Wire);
			   wirelist->fanin = wirelist->fanout = 0;
			   wirelist->name = yypvt[-0].txt;
			 }
			 wirelist->fanin++;
			 wirelist->link_bit = elemlist->outputs;
			 elemlist->outputs++;
			 if(wirelist->elem != NULL){      /*check for inserted delayed wire*/
			   if(wirelist->elem->gatetype == DELAYED_WIRE){
				tempelem = wirelist->elem;		 /*in the case of a delayed wire,*/
				wirelist = MALLOC_TYPE(struct Wire);	 /*create a new internal wire for*/
			   	wirelist->fanin = wirelist->fanout = 1;	 /*the inter-elem connection (this*/
			   	wirelist->name = NULL;			 /*wire is not declared in the source*/ 
				wirelist->conn = MALLOC_TYPE(struct CONNECTION);   /*file, so it must be  */
				wirelist->conn->ept = tempelem;			   /*created here)*/	
			 	tempelem->conn = MALLOC_TYPE(struct CONNECTION);
			 	tempelem->conn->wpt = wirelist;
				HT_TAIL(wirelist, &whead, &wtail);
			 	HT_TAIL(tempelem->conn, &tempelem->cinhead, &tempelem->cintail);
			 	HT_TAIL(wirelist->conn, &wirelist->couthead, &wirelist->couttail);
			   }
			 }
			 wirelist->elem = elemlist;
			 if(!Is_in_list) HT_TAIL(wirelist, &whead, &wtail);
			} break;
case 395:
# line 1538 "verilog.yacc"
{Is_in_list=FALSE;
			 for(wirelist=whead; wirelist; wirelist=wirelist->next)
			        if(!strcmp(wirelist->name,yypvt[-3].txt)){
			           Is_in_list = TRUE;
				   break;
				}
			 if(!Is_in_list){
			   wirelist = MALLOC_TYPE(struct Wire);
			   wirelist->fanin = wirelist->fanout = 0;
			   wirelist->name = yypvt[-3].txt;
			 }
			 wirelist->fanin++;
			 wirelist->link_bit = elemlist->outputs;
			 elemlist->outputs++;
			 if(wirelist->elem != NULL){      /*check for inserted delayed wire*/
			   if(wirelist->elem->gatetype == DELAYED_WIRE){
				tempelem = wirelist->elem;		 /*in the case of a delayed wire,*/
				wirelist = MALLOC_TYPE(struct Wire);	 /*create a new internal wire for*/
			   	wirelist->fanin = wirelist->fanout = 1;	 /*the inter-elem connection (this*/
			   	wirelist->name = NULL;			 /*wire is not declared in the source*/ 
				wirelist->conn = MALLOC_TYPE(struct CONNECTION);   /*file, so it must be  */
				wirelist->conn->ept = tempelem;			   /*created here)*/	
			 	tempelem->conn = MALLOC_TYPE(struct CONNECTION);
			 	tempelem->conn->wpt = wirelist;
				HT_TAIL(wirelist, &whead, &wtail);
			 	HT_TAIL(tempelem->conn, &tempelem->cinhead, &tempelem->cintail);
			 	HT_TAIL(wirelist->conn, &wirelist->couthead, &wirelist->couttail);
			   }
			 }
			 wirelist->elem = elemlist;
			 if(!Is_in_list) HT_TAIL(wirelist, &whead, &wtail);
			} break;
# line	531 "/usr/ccs/bin/yaccpar"
	}
	goto yystack;		/* reset registers in driver code */
}

